@@ -10,6 +10,8 @@ import warnings
 
 from zope.interface import implementer
 
+from webob.cookies import CookieProfile
+
 from pyramid.compat import (
     long,
     text_type,
@@ -18,6 +20,7 @@ from pyramid.compat import (
     url_quote,
     bytes_,
     ascii_native_,
+    native_,
     )
 
 from pyramid.interfaces import (
@@ -333,12 +336,19 @@ class RepozeWho1AuthenticationPolicy(CallbackAuthenticationPolicy):
         return effective_principals
 
     def remember(self, request, principal, **kw):
-        """ Store the ``principal`` as ``repoze.who.userid``."""
+        """ Store the ``principal`` as ``repoze.who.userid``.
+        
+        The identity to authenticated to :mod:`repoze.who`
+        will contain the given principal as ``userid``, and
+        provide all keyword arguments as additional identity
+        keys. Useful keys could be ``max_age`` or ``userdata``.
+        """
         identifier = self._get_identifier(request)
         if identifier is None:
             return []
         environ = request.environ
-        identity = {'repoze.who.userid':principal}
+        identity = kw
+        identity['repoze.who.userid'] = principal
         return identifier.remember(environ, identity)
 
     def forget(self, request):
@@ -424,7 +434,9 @@ class AuthTktAuthenticationPolicy(CallbackAuthenticationPolicy):
 
     ``secret``
 
-       The secret (a string) used for auth_tkt cookie signing.
+       The secret (a string) used for auth_tkt cookie signing.  This value
+       should be unique across all values provided to Pyramid for various
+       subsystem secrets (see :ref:`admonishment_against_secret_sharing`).
        Required.
 
     ``callback``
@@ -450,6 +462,12 @@ class AuthTktAuthenticationPolicy(CallbackAuthenticationPolicy):
        Default: ``False``.  Make the requesting IP address part of
        the authentication data in the cookie.  Optional.
 
+       For IPv6 this option is not recommended. The ``mod_auth_tkt``
+       specification does not specify how to handle IPv6 addresses, so using
+       this option in combination with IPv6 addresses may cause an
+       incompatible cookie. It ties the authentication ticket to that
+       individual's IPv6 address.
+
     ``timeout``
 
        Default: ``None``.  Maximum number of seconds which a newly
@@ -505,9 +523,32 @@ class AuthTktAuthenticationPolicy(CallbackAuthenticationPolicy):
     ``wild_domain``
 
        Default: ``True``. An auth_tkt cookie will be generated for the
-       wildcard domain.
+       wildcard domain. If your site is hosted as ``example.com`` this
+       will make the cookie available for sites underneath ``example.com``
+       such as ``www.example.com``.
        Optional.
 
+    ``parent_domain``
+
+       Default: ``False``. An auth_tkt cookie will be generated for the
+       parent domain of the current site. For example if your site is
+       hosted under ``www.example.com`` a cookie will be generated for
+       ``.example.com``. This can be useful if you have multiple sites
+       sharing the same domain. This option supercedes the ``wild_domain``
+       option.
+       Optional.
+
+       This option is available as of :app:`Pyramid` 1.5.
+
+    ``domain``
+
+       Default: ``None``. If provided the auth_tkt cookie will only be
+       set for this domain. This option is not compatible with ``wild_domain``
+       and ``parent_domain``.
+       Optional.
+
+       This option is available as of :app:`Pyramid` 1.5.
+
     ``hashalg``
 
        Default: ``md5`` (the literal string).
@@ -559,7 +600,9 @@ class AuthTktAuthenticationPolicy(CallbackAuthenticationPolicy):
                  http_only=False,
                  wild_domain=True,
                  debug=False,
-                 hashalg=_marker
+                 hashalg=_marker,
+                 parent_domain=False,
+                 domain=None,
                  ):
         if hashalg is _marker:
             hashalg = 'md5'
@@ -597,6 +640,8 @@ class AuthTktAuthenticationPolicy(CallbackAuthenticationPolicy):
             path=path,
             wild_domain=wild_domain,
             hashalg=hashalg,
+            parent_domain=parent_domain,
+            domain=domain,
             )
         self.callback = callback
         self.debug = debug
@@ -736,9 +781,17 @@ def calculate_digest(ip, timestamp, secret, userid, tokens, user_data,
     tokens = bytes_(tokens, 'utf-8')
     user_data = bytes_(user_data, 'utf-8')
     hash_obj = hashlib.new(hashalg)
-    hash_obj.update(
-        encode_ip_timestamp(ip, timestamp) + secret + userid + b'\0'
-        + tokens + b'\0' + user_data)
+
+    # Check to see if this is an IPv6 address
+    if ':' in ip:
+        ip_timestamp = ip + str(int(timestamp))
+        ip_timestamp = bytes_(ip_timestamp)
+    else:
+        # encode_ip_timestamp not required, left in for backwards compatibility
+        ip_timestamp = encode_ip_timestamp(ip, timestamp)
+
+    hash_obj.update(ip_timestamp + secret + userid + b'\0' +
+            tokens + b'\0' + user_data)
     digest = hash_obj.hexdigest()
     hash_obj2 = hashlib.new(hashalg)
     hash_obj2.update(bytes_(digest) + secret)
@@ -755,8 +808,6 @@ def encode_ip_timestamp(ip, timestamp):
     ts_chars = ''.join(map(chr, ts))
     return bytes_(ip_chars + ts_chars)
 
-EXPIRE = object()
-
 class AuthTktCookieHelper(object):
     """
     A helper class for use in third-party authentication policy
@@ -786,69 +837,55 @@ class AuthTktCookieHelper(object):
     def __init__(self, secret, cookie_name='auth_tkt', secure=False,
                  include_ip=False, timeout=None, reissue_time=None,
                  max_age=None, http_only=False, path="/", wild_domain=True,
-                 hashalg='md5'):
+                 hashalg='md5', parent_domain=False, domain=None):
+
+        serializer = _SimpleSerializer()
+            
+        self.cookie_profile = CookieProfile(
+            cookie_name = cookie_name,
+            secure = secure,
+            max_age = max_age,
+            httponly = http_only,
+            path = path,
+            serializer=serializer
+            )
+
         self.secret = secret
         self.cookie_name = cookie_name
-        self.include_ip = include_ip
         self.secure = secure
+        self.include_ip = include_ip
         self.timeout = timeout
         self.reissue_time = reissue_time
         self.max_age = max_age
-        self.http_only = http_only
-        self.path = path
         self.wild_domain = wild_domain
+        self.parent_domain = parent_domain
+        self.domain = domain
         self.hashalg = hashalg
 
-        static_flags = []
-        if self.secure:
-            static_flags.append('; Secure')
-        if self.http_only:
-            static_flags.append('; HttpOnly')
-        self.static_flags = "".join(static_flags)
+    def _get_cookies(self, request, value, max_age=None):
+        cur_domain = request.domain
 
-    def _get_cookies(self, environ, value, max_age=None):
-        if max_age is EXPIRE:
-            max_age = "; Max-Age=0; Expires=Wed, 31-Dec-97 23:59:59 GMT"
-        elif max_age is not None:
-            later = datetime.datetime.utcnow() + datetime.timedelta(
-                seconds=int(max_age))
-            # Wdy, DD-Mon-YY HH:MM:SS GMT
-            expires = later.strftime('%a, %d %b %Y %H:%M:%S GMT')
-            # the Expires header is *required* at least for IE7 (IE7 does
-            # not respect Max-Age)
-            max_age = "; Max-Age=%s; Expires=%s" % (max_age, expires)
+        domains = []
+        if self.domain:
+            domains.append(self.domain)
         else:
-            max_age = ''
+            if self.parent_domain and cur_domain.count('.') > 1:
+                domains.append('.' + cur_domain.split('.', 1)[1])
+            else:
+                domains.append(None)
+                domains.append(cur_domain)
+                if self.wild_domain:
+                    domains.append('.' + cur_domain)
 
-        cur_domain = environ.get('HTTP_HOST', environ.get('SERVER_NAME'))
+        profile = self.cookie_profile(request)
 
-        # While Chrome, IE, and Firefox can cope, Opera (at least) cannot
-        # cope with a port number in the cookie domain when the URL it
-        # receives the cookie from does not also have that port number in it
-        # (e.g via a proxy).  In the meantime, HTTP_HOST is sent with port
-        # number, and neither Firefox nor Chrome do anything with the
-        # information when it's provided in a cookie domain except strip it
-        # out.  So we strip out any port number from the cookie domain
-        # aggressively to avoid problems.  See also
-        # https://github.com/Pylons/pyramid/issues/131
-        if ':' in cur_domain:
-            cur_domain = cur_domain.split(':', 1)[0]
-
-        cookies = [
-            ('Set-Cookie', '%s="%s"; Path=%s%s%s' % (
-            self.cookie_name, value, self.path, max_age, self.static_flags)),
-            ('Set-Cookie', '%s="%s"; Path=%s; Domain=%s%s%s' % (
-            self.cookie_name, value, self.path, cur_domain, max_age,
-                self.static_flags)),
-            ]
-
-        if self.wild_domain:
-            wild_domain = '.' + cur_domain
-            cookies.append(('Set-Cookie', '%s="%s"; Path=%s; Domain=%s%s%s' % (
-                self.cookie_name, value, self.path, wild_domain, max_age,
-                self.static_flags)))
-
-        return cookies
+        kw = {}
+        kw['domains'] = domains
+        if max_age is not None:
+            kw['max_age'] = max_age
+            
+        headers = profile.get_headers(value, **kw)
+        return headers
 
     def identify(self, request):
         """ Return a dictionary with authentication information, or ``None``
@@ -917,9 +954,8 @@ class AuthTktCookieHelper(object):
     def forget(self, request):
         """ Return a set of expires Set-Cookie headers, which will destroy
         any existing auth_tkt cookie when attached to a response"""
-        environ = request.environ
         request._authtkt_reissue_revoked = True
-        return self._get_cookies(environ, '', max_age=EXPIRE)
+        return self._get_cookies(request, None)
 
     def remember(self, request, userid, max_age=None, tokens=()):
         """ Return a set of Set-Cookie headers; when set into a response,
@@ -986,7 +1022,7 @@ class AuthTktCookieHelper(object):
             )
 
         cookie_value = ticket.cookie_value()
-        return self._get_cookies(environ, cookie_value, max_age)
+        return self._get_cookies(request, cookie_value, max_age)
 
 @implementer(IAuthenticationPolicy)
 class SessionAuthenticationPolicy(CallbackAuthenticationPolicy):
@@ -1075,12 +1111,11 @@ class BasicAuthAuthenticationPolicy(CallbackAuthenticationPolicy):
     register a view that will send a Basic Auth challenge to the user whenever
     there is an attempt to call a view which results in a Forbidden response::
 
-        from pyramid.httpexceptions import HTTPForbidden
         from pyramid.httpexceptions import HTTPUnauthorized
         from pyramid.security import forget
-        from pyramid.view import view_config
+        from pyramid.view import forbidden_view_config
 
-        @view_config(context=HTTPForbidden)
+        @forbidden_view_config()
         def basic_challenge(request):
             response = HTTPUnauthorized()
             response.headers.update(forget(request))
@@ -1128,12 +1163,29 @@ class BasicAuthAuthenticationPolicy(CallbackAuthenticationPolicy):
             return None
         if authmeth.lower() != 'basic':
             return None
+
         try:
-            auth = b64decode(auth.strip()).decode('ascii')
+            authbytes = b64decode(auth.strip())
         except (TypeError, binascii.Error): # can't decode
             return None
+
+        # try utf-8 first, then latin-1; see discussion in
+        # https://github.com/Pylons/pyramid/issues/898
+        try:
+            auth = authbytes.decode('utf-8')
+        except UnicodeDecodeError:
+            auth = authbytes.decode('latin-1')
+
         try:
             username, password = auth.split(':', 1)
         except ValueError: # not enough values to unpack
             return None
         return username, password
+
+class _SimpleSerializer(object):
+    def loads(self, bstruct):
+        return native_(bstruct)
+
+    def dumps(self, appstruct):
+        return bytes_(appstruct)
+
