@@ -4,7 +4,6 @@ import logging
 import operator
 import os
 import sys
-import warnings
 import venusian
 
 from webob.exc import WSGIHTTPException as WebobWSGIHTTPException
@@ -63,14 +62,13 @@ from pyramid.config.adapters import AdaptersConfiguratorMixin
 from pyramid.config.assets import AssetsConfiguratorMixin
 from pyramid.config.factories import FactoriesConfiguratorMixin
 from pyramid.config.i18n import I18NConfiguratorMixin
-from pyramid.config.rendering import DEFAULT_RENDERERS
 from pyramid.config.rendering import RenderingConfiguratorMixin
 from pyramid.config.routes import RoutesConfiguratorMixin
 from pyramid.config.security import SecurityConfiguratorMixin
 from pyramid.config.settings import SettingsConfiguratorMixin
 from pyramid.config.testing import TestingConfiguratorMixin
 from pyramid.config.tweens import TweensConfiguratorMixin
-from pyramid.config.util import PredicateList
+from pyramid.config.util import PredicateList, not_
 from pyramid.config.views import ViewsConfiguratorMixin
 from pyramid.config.zca import ZCAConfiguratorMixin
 
@@ -86,6 +84,9 @@ _marker = object()
 
 ConfigurationError = ConfigurationError # pyflakes
 
+not_ = not_ # pyflakes, this is an API
+
+
 class Configurator(
     TestingConfiguratorMixin,
     TweensConfiguratorMixin,
@@ -104,14 +105,7 @@ class Configurator(
     A Configurator is used to configure a :app:`Pyramid`
     :term:`application registry`.
 
-    The Configurator accepts a number of arguments: ``registry``,
-    ``package``, ``settings``, ``root_factory``, ``authentication_policy``,
-    ``authorization_policy``, ``renderers``, ``debug_logger``,
-    ``locale_negotiator``, ``request_factory``, ``renderer_globals_factory``,
-    ``default_permission``, ``session_factory``, ``default_view_mapper``,
-    ``autocommit``, ``exceptionresponse_view`` and ``route_prefix``.
-
-    If the ``registry`` argument is passed as a non-``None`` value, it must
+    If the ``registry`` argument is not ``None``, it must
     be an instance of the :class:`pyramid.registry.Registry` class
     representing the registry to configure.  If ``registry`` is ``None``, the
     configurator will create a :class:`pyramid.registry.Registry` instance
@@ -119,9 +113,9 @@ class Configurator(
     otherwise be done.  After its construction, the configurator may be used
     to add further configuration to the registry.
 
-    .. warning:: If a ``registry`` is passed to the Configurator
-       constructor, all other constructor arguments except ``package``
-       are ignored.
+    .. warning:: If ``registry`` is assigned the above-mentioned class
+       instance, all other constructor arguments are ignored,
+       with the exception of ``package``.
 
     If the ``package`` argument is passed, it must be a reference to a Python
     :term:`package` (e.g. ``sys.modules['thepackage']``) or a :term:`dotted
@@ -154,12 +148,12 @@ class Configurator(
        authorization policy is supplied without also supplying an
        authentication policy (authorization requires authentication).
 
-    If ``renderers`` is passed, it should be a list of tuples
-    representing a set of :term:`renderer` factories which should be
-    configured into this application (each tuple representing a set of
+    If ``renderers`` is ``None`` (the default), a default set of
+    :term:`renderer` factories is used. Else, it should be a list of
+    tuples representing a set of renderer factories which should be
+    configured into this application, and each tuple representing a set of
     positional values that should be passed to
-    :meth:`pyramid.config.Configurator.add_renderer`).  If
-    it is not passed, a default set of renderer factories is used.
+    :meth:`pyramid.config.Configurator.add_renderer`.
 
     If ``debug_logger`` is not passed, a default debug logger that logs to a
     logger will be used (the logger name will be the package name of the
@@ -177,16 +171,6 @@ class Configurator(
     See :ref:`changing_the_request_factory`.  By default it is ``None``,
     which means use the default request factory.
 
-    If ``renderer_globals_factory`` is passed, it should be a :term:`renderer
-    globals` factory implementation or a :term:`dotted Python name` to the
-    same.  See :ref:`adding_renderer_globals`.  By default, it is ``None``,
-    which means use no renderer globals factory.
-
-    .. warning::
-
-       as of Pyramid 1.1, ``renderer_globals_factory`` is deprecated.  Instead,
-       use a BeforeRender event subscriber as per :ref:`beforerender_event`.
-
     If ``default_permission`` is passed, it should be a
     :term:`permission` string to be used as the default permission for
     all view configuration registrations performed against this
@@ -197,8 +181,11 @@ class Configurator(
     By default, ``default_permission`` is ``None``, meaning that view
     configurations which do not explicitly declare a permission will
     always be executable by entirely anonymous users (any
-    authorization policy in effect is ignored).  See also
-    :ref:`setting_a_default_permission`.
+    authorization policy in effect is ignored).
+    
+    .. seealso::
+
+        See also :ref:`setting_a_default_permission`.
 
     If ``session_factory`` is passed, it should be an object which
     implements the :term:`session factory` interface.  If a nondefault
@@ -218,15 +205,15 @@ class Configurator(
     :meth:`pyramid.config.Configurator.commit` is called.  When
     :meth:`pyramid.config.Configurator.commit` is called, the actions implied
     by the called methods will be checked for configuration conflicts unless
-    ``autocommit`` is ``True``.  If a conflict is detected a
+    ``autocommit`` is ``True``.  If a conflict is detected, a
     ``ConfigurationConflictError`` will be raised.  Calling
     :meth:`pyramid.config.Configurator.make_wsgi_app` always implies a final
     commit.
 
     If ``default_view_mapper`` is passed, it will be used as the default
     :term:`view mapper` factory for view configurations that don't otherwise
-    specify one (see :class:`pyramid.interfaces.IViewMapperFactory`).  If a
-    default_view_mapper is not passed, a superdefault view mapper will be
+    specify one (see :class:`pyramid.interfaces.IViewMapperFactory`).  If
+    ``default_view_mapper`` is not passed, a superdefault view mapper will be
     used.
 
     If ``exceptionresponse_view`` is passed, it must be a :term:`view
@@ -236,18 +223,26 @@ class Configurator(
     be registered, and all raised exception responses will be bubbled up to
     Pyramid's caller.  By
     default, the ``pyramid.httpexceptions.default_exceptionresponse_view``
-    function is used as the ``exceptionresponse_view``.  This argument is new
-    in Pyramid 1.1.
+    function is used as the ``exceptionresponse_view``.
 
     If ``route_prefix`` is passed, all routes added with
     :meth:`pyramid.config.Configurator.add_route` will have the specified path
-    prepended to their pattern. This parameter is new in Pyramid 1.2.
+    prepended to their pattern.
 
     If ``introspection`` is passed, it must be a boolean value.  If it's
     ``True``, introspection values during actions will be kept for use
     for tools like the debug toolbar.  If it's ``False``, introspection
     values provided by registrations will be ignored.  By default, it is
-    ``True``.  This parameter is new as of Pyramid 1.3.
+    ``True``.
+
+    .. versionadded:: 1.1
+       The ``exceptionresponse_view`` argument.
+
+    .. versionadded:: 1.2
+       The ``route_prefix`` argument.
+
+    .. versionadded:: 1.3
+       The ``introspection`` argument.
     """
     manager = manager # for testing injection
     venusian = venusian # for testing injection
@@ -270,7 +265,6 @@ class Configurator(
                  debug_logger=None,
                  locale_negotiator=None,
                  request_factory=None,
-                 renderer_globals_factory=None,
                  default_permission=None,
                  session_factory=None,
                  default_view_mapper=None,
@@ -301,7 +295,6 @@ class Configurator(
                 debug_logger=debug_logger,
                 locale_negotiator=locale_negotiator,
                 request_factory=request_factory,
-                renderer_globals_factory=renderer_globals_factory,
                 default_permission=default_permission,
                 session_factory=session_factory,
                 default_view_mapper=default_view_mapper,
@@ -317,7 +310,6 @@ class Configurator(
                        debug_logger=None,
                        locale_negotiator=None,
                        request_factory=None,
-                       renderer_globals_factory=None,
                        default_permission=None,
                        session_factory=None,
                        default_view_mapper=None,
@@ -344,7 +336,6 @@ class Configurator(
         self._fix_registry()
 
         self._set_settings(settings)
-        self._register_response_adapters()
 
         if isinstance(debug_logger, string_types):
             debug_logger = logging.getLogger(debug_logger)
@@ -354,9 +345,8 @@ class Configurator(
 
         registry.registerUtility(debug_logger, IDebugLogger)
 
-        for name, renderer in DEFAULT_RENDERERS:
-            self.add_renderer(name, renderer)
-
+        self.add_default_response_adapters()
+        self.add_default_renderers()
         self.add_default_view_predicates()
         self.add_default_route_predicates()
 
@@ -375,12 +365,12 @@ class Configurator(
 
         self.commit()
 
-        # self.commit() should not be called after this point because the
-        # following registrations should be treated as analogues of methods
-        # called by the user after configurator construction.  Rationale:
-        # user-supplied implementations should be preferred rather than
-        # add-on author implementations with the help of automatic conflict
-        # resolution.
+        # self.commit() should not be called within this method after this
+        # point because the following registrations should be treated as
+        # analogues of methods called by the user after configurator
+        # construction.  Rationale: user-supplied implementations should be
+        # preferred rather than add-on author implementations with the help of
+        # automatic conflict resolution.
 
         if authentication_policy and not authorization_policy:
             authorization_policy = ACLAuthorizationPolicy() # default
@@ -407,17 +397,6 @@ class Configurator(
         if request_factory:
             self.set_request_factory(request_factory)
 
-        if renderer_globals_factory:
-            warnings.warn(
-                'Passing ``renderer_globals_factory`` as a Configurator '
-                'constructor parameter is deprecated as of Pyramid 1.1. '
-                'Use a BeforeRender event subscriber as documented in the '
-                '"Hooks" chapter of the Pyramid narrative documentation '
-                'instead',
-                DeprecationWarning,
-                2)
-            self.set_renderer_globals_factory(renderer_globals_factory,
-                                              warn=False)
         if default_permission:
             self.set_default_permission(default_permission)
 
@@ -502,6 +481,7 @@ class Configurator(
 
     def _add_predicate(self, type, name, factory, weighs_more_than=None,
                        weighs_less_than=None):
+        factory = self.maybe_dotted(factory)
         discriminator = ('%s predicate' % type, name)
         intr = self.introspectable(
             '%s predicates' % type,
@@ -631,7 +611,7 @@ class Configurator(
         self.action_state = ActionState() # old actions have been processed
 
     def include(self, callable, route_prefix=None):
-        """Include a configuration callables, to support imperative
+        """Include a configuration callable, to support imperative
         application extensibility.
 
         .. warning:: In versions of :app:`Pyramid` prior to 1.2, this
@@ -640,9 +620,9 @@ class Configurator(
 
         A configuration callable should be a callable that accepts a single
         argument named ``config``, which will be an instance of a
-        :term:`Configurator`  (be warned that it will not be the same
-        configurator instance on which you call this method, however).  The
-        code which runs as the result of calling the callable should invoke
+        :term:`Configurator`.  However, be warned that it will not be the same
+        configurator instance on which you call this method.  The
+        code which runs as a result of calling the callable should invoke
         methods on the configurator passed to it which add configuration
         state.  The return value of a callable will be ignored.
 
@@ -668,7 +648,7 @@ class Configurator(
            def includeme(config):
                config.add_view(my_view)
 
-        You might cause it be included within your Pyramid application like
+        You might cause it to be included within your Pyramid application like
         so:
 
         .. code-block:: python
@@ -701,7 +681,7 @@ class Configurator(
         to :meth:`pyramid.config.Configurator.add_route` within the included
         callable will have their pattern prefixed with the value of
         ``route_prefix``. This can be used to help mount a set of routes at a
-        different location than the included callable's author intended while
+        different location than the included callable's author intended, while
         still maintaining the same route names.  For example:
 
         .. code-block:: python
@@ -721,7 +701,9 @@ class Configurator(
         because the ``route_prefix`` argument will be prepended to the
         pattern.
 
-        The ``route_prefix`` parameter is new as of Pyramid 1.2.
+        .. versionadded:: 1.2
+           The ``route_prefix`` parameter.
+
         """
         # """ <-- emacs
 
@@ -819,10 +801,8 @@ class Configurator(
 
     def with_package(self, package):
         """ Return a new Configurator instance with the same registry
-        as this configurator using the package supplied as the
-        ``package`` argument to the new configurator.  ``package`` may
-        be an actual Python package object or a :term:`dotted Python name`
-        representing a package."""
+        as this configurator. ``package`` may be an actual Python package
+        object or a :term:`dotted Python name` representing a package."""
         configurator = self.__class__(
             registry=self.registry,
             package=package,
@@ -864,14 +844,14 @@ class Configurator(
         This pushes a dictionary containing the :term:`application
         registry` implied by ``registry`` attribute of this
         configurator and the :term:`request` implied by the
-        ``request`` argument on to the :term:`thread local` stack
+        ``request`` argument onto the :term:`thread local` stack
         consulted by various :mod:`pyramid.threadlocal` API
         functions."""
         self.manager.push({'registry':self.registry, 'request':request})
 
     def end(self):
         """ Indicate that application or test configuration has ended.
-        This pops the last value pushed on to the :term:`thread local`
+        This pops the last value pushed onto the :term:`thread local`
         stack (usually by the ``begin`` method) and returns that
         value.
         """
@@ -919,8 +899,6 @@ class Configurator(
         and scanned.  See the :term:`Venusian` documentation for more
         information about the ``ignore`` argument.
 
-        .. note:: the ``ignore`` argument is new in Pyramid 1.3.
-        
         To perform a ``scan``, Pyramid creates a Venusian ``Scanner`` object.
         The ``kw`` argument represents a set of keyword arguments to pass to
         the Venusian ``Scanner`` object's constructor.  See the
@@ -932,7 +910,12 @@ class Configurator(
         may require additional arguments.  Providing this argument is not
         often necessary; it's an advanced usage.
 
-        .. note:: the ``**kw`` argument is new in Pyramid 1.1
+        .. versionadded:: 1.1
+           The ``**kw`` argument.
+
+        .. versionadded:: 1.3
+           The ``ignore`` argument.
+
         """
         package = self.maybe_dotted(package)
         if package is None: # pragma: no cover
@@ -960,7 +943,7 @@ class Configurator(
         # registry configured.
         global_registries.add(self.registry)
 
-        # Push the registry on to the stack in case any code that depends on
+        # Push the registry onto the stack in case any code that depends on
         # the registry threadlocal APIs used in listeners subscribed to the
         # IApplicationCreated event.
         self.manager.push({'registry':self.registry, 'request':None})
@@ -1049,7 +1032,7 @@ class ActionState(object):
         ...    v = context.execute_actions()
         ... except ConfigurationExecutionError, v:
         ...    pass
-        >>> print v
+        >>> print(v)
         exceptions.AttributeError: 'function' object has no attribute 'xxx'
           in:
           oops
