@@ -1,5 +1,6 @@
 import warnings
 
+from pyramid.compat import urlparse
 from pyramid.interfaces import (
     IRequest,
     IRouteRequest,
@@ -24,8 +25,6 @@ class RoutesConfiguratorMixin(object):
     def add_route(self,
                   name,
                   pattern=None,
-                  view=None,
-                  view_for=None,
                   permission=None,
                   factory=None,
                   for_=None,
@@ -37,11 +36,6 @@ class RoutesConfiguratorMixin(object):
                   request_param=None,
                   traverse=None,
                   custom_predicates=(),
-                  view_permission=None,
-                  renderer=None,
-                  view_renderer=None,
-                  view_context=None,
-                  view_attr=None,
                   use_global_views=False,
                   path=None,
                   pregenerator=None,
@@ -90,10 +84,10 @@ class RoutesConfiguratorMixin(object):
           ``traverse`` argument provided to ``add_route`` is
           ``/{article}``, when a request comes in that causes the route
           to match in such a way that the ``article`` match value is
-          '1' (when the request URI is ``/articles/1/edit``), the
+          ``'1'`` (when the request URI is ``/articles/1/edit``), the
           traversal path will be generated as ``/1``.  This means that
           the root object's ``__getitem__`` will be called with the
-          name ``1`` during the traversal phase.  If the ``1`` object
+          name ``'1'`` during the traversal phase.  If the ``'1'`` object
           exists, it will become the :term:`context` of the request.
           :ref:`traversal_chapter` has more information about
           traversal.
@@ -142,7 +136,7 @@ class RoutesConfiguratorMixin(object):
           request; it will only be useful for URL generation.  By default,
           ``static`` is ``False``.  See :ref:`static_route_narr`.
 
-          .. note:: New in :app:`Pyramid` 1.1.
+          .. versionadded:: 1.1
 
         Predicate Arguments
 
@@ -180,9 +174,9 @@ class RoutesConfiguratorMixin(object):
           will match if the request has *any* request method.  If this
           predicate returns ``False``, route matching continues.
 
-          .. note:: The ability to pass a tuple of items as
-                   ``request_method`` is new as of Pyramid 1.2.  Previous
-                   versions allowed only a string.
+          .. versionchanged:: 1.2
+             The ability to pass a tuple of items as ``request_method``.
+             Previous versions allowed only a string.
 
         path_info
 
@@ -235,17 +229,18 @@ class RoutesConfiguratorMixin(object):
           wildcard mimetype match token in the form ``text/*`` or a
           match-all wildcard mimetype match token in the form ``*/*``.
           If any of the forms matches the ``Accept`` header of the
-          request, this predicate will be true.  If this predicate
+          request, or if the ``Accept`` header isn't set at all in the
+          request, this predicate will be true. If this predicate
           returns ``False``, route matching continues.
 
         effective_principals
 
           If specified, this value should be a :term:`principal` identifier or
           a sequence of principal identifiers.  If the
-          :func:`pyramid.security.effective_principals` method indicates that
-          every principal named in the argument list is present in the current
-          request, this predicate will return True; otherwise it will return
-          False.  For example:
+          :attr:`pyramid.request.Request.effective_principals` property
+          indicates that every principal named in the argument list is present
+          in the current request, this predicate will return True; otherwise it
+          will return False.  For example:
           ``effective_principals=pyramid.security.Authenticated`` or
           ``effective_principals=('fred', 'group:admins')``.
 
@@ -253,21 +248,22 @@ class RoutesConfiguratorMixin(object):
 
         custom_predicates
 
-          This value should be a sequence of references to custom
-          predicate callables.  Use custom predicates when no set of
-          predefined predicates does what you need.  Custom predicates
-          can be combined with predefined predicates as necessary.
-          Each custom predicate callable should accept two arguments:
-          ``info`` and ``request`` and should return either ``True``
-          or ``False`` after doing arbitrary evaluation of the info
-          and/or the request.  If all custom and non-custom predicate
-          callables return ``True`` the associated route will be
-          considered viable for a given request.  If any predicate
-          callable returns ``False``, route matching continues.  Note
-          that the value ``info`` passed to a custom route predicate
-          is a dictionary containing matching information; see
-          :ref:`custom_route_predicates` for more information about
-          ``info``.
+          .. deprecated:: 1.5
+              This value should be a sequence of references to custom
+              predicate callables.  Use custom predicates when no set of
+              predefined predicates does what you need.  Custom predicates
+              can be combined with predefined predicates as necessary.
+              Each custom predicate callable should accept two arguments:
+              ``info`` and ``request`` and should return either ``True``
+              or ``False`` after doing arbitrary evaluation of the info
+              and/or the request.  If all custom and non-custom predicate
+              callables return ``True`` the associated route will be
+              considered viable for a given request.  If any predicate
+              callable returns ``False``, route matching continues.  Note
+              that the value ``info`` passed to a custom route predicate
+              is a dictionary containing matching information; see
+              :ref:`custom_route_predicates` for more information about
+              ``info``.
 
         predicates
 
@@ -276,100 +272,23 @@ class RoutesConfiguratorMixin(object):
           :meth:`pyramid.config.Configurator.add_view_predicate`.  More than
           one key/value pair can be used at the same time.  See
           :ref:`view_and_route_predicates` for more information about
-          third-party predicates.  This argument is new as of Pyramid 1.4.
-          
-        View-Related Arguments
+          third-party predicates.
 
-        .. warning::
-
-           The arguments described below have been deprecated as of
-           :app:`Pyramid` 1.1. *Do not use these for new development; they
-           should only be used to support older code bases which depend upon
-           them.* Use a separate call to
-           :meth:`pyramid.config.Configurator.add_view` to associate a view
-           with a route using the ``route_name`` argument.
-
-        view
-
-          .. warning:: Deprecated as of :app:`Pyramid` 1.1.
-
-          A Python object or :term:`dotted Python name` to the same
-          object that will be used as a view callable when this route
-          matches. e.g. ``mypackage.views.my_view``.
-
-        view_context
-
-          .. warning:: Deprecated as of :app:`Pyramid` 1.1.
-
-          A class or an :term:`interface` or :term:`dotted Python
-          name` to the same object which the :term:`context` of the
-          view should match for the view named by the route to be
-          used.  This argument is only useful if the ``view``
-          attribute is used.  If this attribute is not specified, the
-          default (``None``) will be used.
-
-          If the ``view`` argument is not provided, this argument has
-          no effect.
-
-          This attribute can also be spelled as ``for_`` or ``view_for``.
-
-        view_permission
-
-          .. warning:: Deprecated as of :app:`Pyramid` 1.1.
-
-          The permission name required to invoke the view associated
-          with this route.  e.g. ``edit``. (see
-          :ref:`using_security_with_urldispatch` for more information
-          about permissions).
-
-          If the ``view`` attribute is not provided, this argument has
-          no effect.
-
-          This argument can also be spelled as ``permission``.
-
-        view_renderer
-
-          .. warning:: Deprecated as of :app:`Pyramid` 1.1.
-
-          This is either a single string term (e.g. ``json``) or a
-          string implying a path or :term:`asset specification`
-          (e.g. ``templates/views.pt``).  If the renderer value is a
-          single term (does not contain a dot ``.``), the specified
-          term will be used to look up a renderer implementation, and
-          that renderer implementation will be used to construct a
-          response from the view return value.  If the renderer term
-          contains a dot (``.``), the specified term will be treated
-          as a path, and the filename extension of the last element in
-          the path will be used to look up the renderer
-          implementation, which will be passed the full path.  The
-          renderer implementation will be used to construct a response
-          from the view return value.  See
-          :ref:`views_which_use_a_renderer` for more information.
-
-          If the ``view`` argument is not provided, this argument has
-          no effect.
-
-          This argument can also be spelled as ``renderer``.
-
-        view_attr
-
-          .. warning:: Deprecated as of :app:`Pyramid` 1.1.
-
-          The view machinery defaults to using the ``__call__`` method
-          of the view callable (or the function itself, if the view
-          callable is a function) to obtain a response dictionary.
-          The ``attr`` value allows you to vary the method attribute
-          used to obtain the response.  For example, if your view was
-          a class, and the class has a method named ``index`` and you
-          wanted to use this method instead of the class' ``__call__``
-          method to return the response, you'd say ``attr="index"`` in
-          the view configuration for the view.  This is
-          most useful when the view definition is a class.
-
-          If the ``view`` argument is not provided, this argument has no
-          effect.
+          .. versionadded:: 1.4
 
         """
+        if custom_predicates:
+            warnings.warn(
+                ('The "custom_predicates" argument to Configurator.add_route '
+                 'is deprecated as of Pyramid 1.5.  Use '
+                 '"config.add_route_predicate" and use the registered '
+                 'route predicate as a predicate argument to add_route '
+                 'instead. See "Adding A Third Party View, Route, or '
+                 'Subscriber Predicate" in the "Hooks" chapter of the '
+                 'documentation for more information.'),
+                DeprecationWarning,
+                stacklevel=3
+                )
         # these are route predicates; if they do not match, the next route
         # in the routelist will be tried
         if request_method is not None:
@@ -381,7 +300,39 @@ class RoutesConfiguratorMixin(object):
         if pattern is None:
             raise ConfigurationError('"pattern" argument may not be None')
 
-        if self.route_prefix:
+        # check for an external route; an external route is one which is
+        # is a full url (e.g. 'http://example.com/{id}')
+        parsed = urlparse.urlparse(pattern)
+        if parsed.hostname:
+            pattern = parsed.path
+
+            original_pregenerator = pregenerator
+            def external_url_pregenerator(request, elements, kw):
+                if '_app_url' in kw:
+                    raise ValueError(
+                        'You cannot generate a path to an external route '
+                        'pattern via request.route_path nor pass an _app_url '
+                        'to request.route_url when generating a URL for an '
+                        'external route pattern (pattern was "%s") ' %
+                        (pattern,)
+                        )
+                if '_scheme' in kw:
+                    scheme = kw['_scheme']
+                elif parsed.scheme:
+                    scheme = parsed.scheme
+                else:
+                    scheme = request.scheme
+                kw['_app_url'] = '{0}://{1}'.format(scheme, parsed.netloc)
+
+                if original_pregenerator:
+                    elements, kw = original_pregenerator(
+                        request, elements, kw)
+                return elements, kw
+
+            pregenerator = external_url_pregenerator
+            static = True
+
+        elif self.route_prefix:
             pattern = self.route_prefix.rstrip('/') + '/' + pattern.lstrip('/')
 
         mapper = self.get_routes_mapper()
@@ -463,19 +414,6 @@ class RoutesConfiguratorMixin(object):
         self.action(('route', name), register_route_request_iface,
                     order=PHASE2_CONFIG, introspectables=introspectables)
 
-        # deprecated adding views from add_route; must come after
-        # route registration for purposes of autocommit ordering
-        if any([view, view_context, view_permission, view_renderer,
-                view_for, for_, permission, renderer, view_attr]):
-            self._add_view_from_route(
-                route_name=name,
-                view=view,
-                permission=view_permission or permission,
-                context=view_context or view_for or for_,
-                renderer=view_renderer or renderer,
-                attr=view_attr,
-            )
-
     @action_method
     def add_route_predicate(self, name, factory, weighs_more_than=None,
                            weighs_less_than=None):
@@ -487,13 +425,12 @@ class RoutesConfiguratorMixin(object):
         Python identifier (it will be used as a keyword argument to
         ``add_view``).
 
-        ``factory`` should be a :term:`predicate factory`.
+        ``factory`` should be a :term:`predicate factory` or :term:`dotted
+        Python name` which refers to a predicate factory.
 
         See :ref:`view_and_route_predicates` for more information.
 
-        .. note::
-
-           This method is new as of Pyramid 1.4.
+        .. versionadded:: 1.4
         """
         self._add_predicate(
             'route',
@@ -517,7 +454,7 @@ class RoutesConfiguratorMixin(object):
             ('traverse', p.TraversePredicate),
             ):
             self.add_route_predicate(name, factory)
-    
+
     def get_routes_mapper(self):
         """ Return the :term:`routes mapper` object associated with
         this configurator's :term:`registry`."""
@@ -527,49 +464,3 @@ class RoutesConfiguratorMixin(object):
             self.registry.registerUtility(mapper, IRoutesMapper)
         return mapper
 
-    def _add_view_from_route(self,
-                             route_name,
-                             view,
-                             context,
-                             permission,
-                             renderer,
-                             attr,
-                             ):
-        if view:
-            self.add_view(
-                permission=permission,
-                context=context,
-                view=view,
-                name='',
-                route_name=route_name,
-                renderer=renderer,
-                attr=attr,
-                )
-        else:
-            # prevent mistakes due to misunderstanding of how hybrid calls to
-            # add_route and add_view interact
-            if attr:
-                raise ConfigurationError(
-                    'view_attr argument not permitted without view '
-                    'argument')
-            if context:
-                raise ConfigurationError(
-                    'view_context argument not permitted without view '
-                    'argument')
-            if permission:
-                raise ConfigurationError(
-                    'view_permission argument not permitted without view '
-                    'argument')
-            if renderer:
-                raise ConfigurationError(
-                    'view_renderer argument not permitted without '
-                    'view argument')
-
-        warnings.warn(
-            'Passing view-related arguments to add_route() is deprecated as of '
-            'Pyramid 1.1.  Use add_view() to associate a view with a route '
-            'instead.  See "Deprecations" in "What\'s New in Pyramid 1.1" '
-            'within the general Pyramid documentation for further details.',
-            DeprecationWarning,
-            4)
-
