@@ -1,6 +1,7 @@
 import inspect
 import operator
 import os
+import warnings
 
 from zope.interface import (
     Interface,
@@ -43,6 +44,11 @@ from pyramid.compat import (
     is_nonstr_iter
     )
 
+from pyramid.encode import (
+    quote_plus,
+    urlencode,
+)
+
 from pyramid.exceptions import (
     ConfigurationError,
     PredicateMismatch,
@@ -64,6 +70,8 @@ from pyramid.security import NO_PERMISSION_REQUIRED
 from pyramid.static import static_view
 from pyramid.threadlocal import get_current_registry
 
+from pyramid.url import parse_url_overrides
+
 from pyramid.view import (
     render_view_to_response,
     AppendSlashNotFoundViewFactory,
@@ -712,7 +720,7 @@ class ViewsConfiguratorMixin(object):
 
         http_cache
 
-          .. note:: This feature is new as of Pyramid 1.1.
+          .. versionadded:: 1.1
 
           When you supply an ``http_cache`` value to a view configuration,
           the ``Expires`` and ``Cache-Control`` headers of a response
@@ -824,7 +832,8 @@ class ViewsConfiguratorMixin(object):
           think about preserving function attributes such as ``__name__`` and
           ``__module__`` within decorator logic).
 
-          Passing an iterable is only supported as of :app:`Pyramid` 1.4a4.
+          .. versionchanged:: 1.4a4
+             Passing an iterable.
 
         mapper
 
@@ -870,18 +879,18 @@ class ViewsConfiguratorMixin(object):
 
         request_method
 
-          This value can be one of the strings ``GET``, ``POST``, ``PUT``,
-          ``DELETE``, or ``HEAD`` representing an HTTP ``REQUEST_METHOD``, or
-          a tuple containing one or more of these strings.  A view
-          declaration with this argument ensures that the view will only be
-          called when the request's ``method`` attribute (aka the
-          ``REQUEST_METHOD`` of the WSGI environment) string matches a
-          supplied value.  Note that use of ``GET`` also implies that the
+          This value can be either a strings (such as ``GET``, ``POST``,
+          ``PUT``, ``DELETE``, or ``HEAD``) representing an HTTP
+          ``REQUEST_METHOD``, or a tuple containing one or more of these
+          strings.  A view declaration with this argument ensures that the
+          view will only be called when the ``method`` attribute of the
+          request (aka the ``REQUEST_METHOD`` of the WSGI environment) matches
+          a supplied value.  Note that use of ``GET`` also implies that the
           view will respond to ``HEAD`` as of Pyramid 1.4.
 
-          .. note:: The ability to pass a tuple of items as
-                   ``request_method`` is new as of Pyramid 1.2.  Previous
-                   versions allowed only a string.
+          .. versionchanged:: 1.2
+             The ability to pass a tuple of items as ``request_method``.
+             Previous versions allowed only a string.
 
         request_param
 
@@ -899,7 +908,7 @@ class ViewsConfiguratorMixin(object):
 
         match_param
 
-          .. note:: This feature is new as of :app:`Pyramid` 1.2.
+          .. versionadded:: 1.2
 
           This value can be a string of the format "key=value" or a tuple
           containing one or more of these strings.
@@ -907,7 +916,7 @@ class ViewsConfiguratorMixin(object):
           A view declaration with this argument ensures that the view will
           only be called when the :term:`request` has key/value pairs in its
           :term:`matchdict` that equal those supplied in the predicate.
-          e.g. ``match_param="action=edit" would require the ``action``
+          e.g. ``match_param="action=edit"`` would require the ``action``
           parameter in the :term:`matchdict` match the right hand side of
           the expression (``edit``) for the view to "match" the current
           request.
@@ -1015,10 +1024,10 @@ class ViewsConfiguratorMixin(object):
 
           If specified, this value should be a :term:`principal` identifier or
           a sequence of principal identifiers.  If the
-          :func:`pyramid.security.effective_principals` method indicates that
-          every principal named in the argument list is present in the current
-          request, this predicate will return True; otherwise it will return
-          False.  For example:
+          :attr:`pyramid.request.Request.effective_principals` property
+          indicates that every principal named in the argument list is present
+          in the current request, this predicate will return True; otherwise it
+          will return False.  For example:
           ``effective_principals=pyramid.security.Authenticated`` or
           ``effective_principals=('fred', 'group:admins')``.
 
@@ -1026,16 +1035,20 @@ class ViewsConfiguratorMixin(object):
 
         custom_predicates
 
-          This value should be a sequence of references to custom predicate
-          callables.  Use custom predicates when no set of predefined
-          predicates do what you need.  Custom predicates can be combined with
-          predefined predicates as necessary.  Each custom predicate callable
-          should accept two arguments: ``context`` and ``request`` and should
-          return either ``True`` or ``False`` after doing arbitrary evaluation
-          of the context and/or the request.  The ``predicates`` argument to
-          this method and the ability to register third-party view predicates
-          via :meth:`pyramid.config.Configurator.add_view_predicate` obsoletes
-          this argument, but it is kept around for backwards compatibility.
+            .. deprecated:: 1.5
+                This value should be a sequence of references to custom
+                predicate callables.  Use custom predicates when no set of
+                predefined predicates do what you need.  Custom predicates
+                can be combined with predefined predicates as necessary. 
+                Each custom predicate callable should accept two arguments:
+                ``context`` and ``request`` and should return either
+                ``True`` or ``False`` after doing arbitrary evaluation of
+                the context and/or the request.  The ``predicates`` argument
+                to this method and the ability to register third-party view
+                predicates via
+                :meth:`pyramid.config.Configurator.add_view_predicate`
+                obsoletes this argument, but it is kept around for backwards
+                compatibility.
 
         predicates
 
@@ -1049,6 +1062,19 @@ class ViewsConfiguratorMixin(object):
           .. versionadded: 1.4a1
 
         """
+        if custom_predicates:
+            warnings.warn(
+                ('The "custom_predicates" argument to Configurator.add_view '
+                 'is deprecated as of Pyramid 1.5.  Use '
+                 '"config.add_view_predicate" and use the registered '
+                 'view predicate as a predicate argument to add_view instead. '
+                 'See "Adding A Third Party View, Route, or Subscriber '
+                 'Predicate" in the "Hooks" chapter of the documentation '
+                 'for more information.'),
+                DeprecationWarning,
+                stacklevel=4
+                )
+        
         view = self.maybe_dotted(view)
         context = self.maybe_dotted(context)
         for_ = self.maybe_dotted(for_)
@@ -1132,6 +1158,8 @@ class ViewsConfiguratorMixin(object):
                 attr, self.object_description(view))
         else:
             view_desc = self.object_description(view)
+
+        tmpl_intr = None
             
         view_intr = self.introspectable('views',
                                         discriminator,
@@ -1182,7 +1210,8 @@ class ViewsConfiguratorMixin(object):
                     renderer = renderers.RendererHelper(
                         name=None,
                         package=self.package,
-                        registry=self.registry)
+                        registry=self.registry
+                        )
 
             if permission is None:
                 # intent: will be None if no default permission is registered
@@ -1313,6 +1342,22 @@ class ViewsConfiguratorMixin(object):
                         multiview,
                         (IExceptionViewClassifier, request_iface, context),
                         IMultiView, name=name)
+            renderer_type = getattr(renderer, 'type', None) # gard against None
+            intrspc = self.introspector
+            if (
+                renderer_type is not None and
+                tmpl_intr is not None and
+                intrspc is not None and
+                intrspc.get('renderer factories', renderer_type) is not None
+                ):
+                # allow failure of registered template factories to be deferred
+                # until view execution, like other bad renderer factories; if
+                # we tried to relate this to an existing renderer factory
+                # without checking if it the factory actually existed, we'd end
+                # up with a KeyError at startup time, which is inconsistent
+                # with how other bad renderer registrations behave (they throw
+                # a ValueError at view execution time)
+                tmpl_intr.relate('renderer factories', renderer.type)
 
         if mapper:
             mapper_intr = self.introspectable(
@@ -1338,7 +1383,6 @@ class ViewsConfiguratorMixin(object):
             tmpl_intr['name'] = renderer.name
             tmpl_intr['type'] = renderer.type
             tmpl_intr['renderer'] = renderer
-            tmpl_intr.relate('renderer factories', renderer.type)
             introspectables.append(tmpl_intr)
         if permission is not None:
             # if a permission exists, register a permission introspectable
@@ -1356,7 +1400,10 @@ class ViewsConfiguratorMixin(object):
     @action_method
     def add_view_predicate(self, name, factory, weighs_more_than=None,
                            weighs_less_than=None):
-        """ Adds a view predicate factory.  The associated view predicate can
+        """
+        .. versionadded:: 1.4
+
+        Adds a view predicate factory.  The associated view predicate can
         later be named as a keyword argument to
         :meth:`pyramid.config.Configurator.add_view` in the
         ``predicates`` anonyous keyword argument dictionary.
@@ -1365,13 +1412,10 @@ class ViewsConfiguratorMixin(object):
         Python identifier (it will be used as a keyword argument to
         ``add_view`` by others).
 
-        ``factory`` should be a :term:`predicate factory`.
+        ``factory`` should be a :term:`predicate factory` or :term:`dotted
+        Python name` which refers to a predicate factory.
 
         See :ref:`view_and_route_predicates` for more information.
-
-        .. note::
-
-           This method is new as of Pyramid 1.4.
         """
         self._add_predicate(
             'view',
@@ -1515,6 +1559,7 @@ class ViewsConfiguratorMixin(object):
 
         return deriver(view)
 
+    @viewdefaults
     @action_method
     def add_forbidden_view(
         self,
@@ -1559,9 +1604,7 @@ class ViewsConfiguratorMixin(object):
         ``for_``, or ``http_cache`` keyword arguments.  These argument values
         make no sense in the context of a forbidden view.
 
-        .. note::
-
-           This method is new as of Pyramid 1.3.
+        .. versionadded:: 1.3
         """
         for arg in ('name', 'permission', 'context', 'for_', 'http_cache'):
             if arg in predicates:
@@ -1596,6 +1639,7 @@ class ViewsConfiguratorMixin(object):
 
     set_forbidden_view = add_forbidden_view # deprecated sorta-bw-compat alias
     
+    @viewdefaults
     @action_method
     def add_notfound_view(
         self,
@@ -1619,9 +1663,9 @@ class ViewsConfiguratorMixin(object):
         append_slash=False,
         **predicates
         ):
-        """ Add a default notfound view to the current configuration state.
+        """ Add a default Not Found View to the current configuration state.
         The view will be called when Pyramid or application code raises an
-        :exc:`pyramid.httpexceptions.HTTPForbidden` exception (e.g. when a
+        :exc:`pyramid.httpexceptions.HTTPNotFound` exception (e.g. when a
         view cannot be found for the request).  The simplest example is:
 
           .. code-block:: python
@@ -1638,9 +1682,9 @@ class ViewsConfiguratorMixin(object):
         :meth:`pyramid.config.Configurator.add_view`, this method will raise
         an exception if passed ``name``, ``permission``, ``context``,
         ``for_``, or ``http_cache`` keyword arguments.  These argument values
-        make no sense in the context of a notfound view.
+        make no sense in the context of a Not Found View.
 
-        If ``append_slash`` is ``True``, when this notfound view is invoked,
+        If ``append_slash`` is ``True``, when this Not Found View is invoked,
         and the current path info does not end in a slash, the notfound logic
         will attempt to find a :term:`route` that matches the request's path
         info suffixed with a slash.  If such a route exists, Pyramid will
@@ -1648,9 +1692,7 @@ class ViewsConfiguratorMixin(object):
         Pyramid will return the result of the view callable provided as
         ``view``, as normal.
 
-        .. note::
-
-           This method is new as of Pyramid 1.3.
+        .. versionadded:: 1.3
         """
         for arg in ('name', 'permission', 'context', 'for_', 'http_cache'):
             if arg in predicates:
@@ -1704,7 +1746,9 @@ class ViewsConfiguratorMixin(object):
         the default view mapper to be used by all subsequent :term:`view
         configuration` registrations.
 
-        See also :ref:`using_a_view_mapper`.
+        .. seealso::
+
+            See also :ref:`using_a_view_mapper`.
 
         .. note::
 
@@ -1799,6 +1843,10 @@ class ViewsConfiguratorMixin(object):
         qualified URL (e.g. starts with ``http://`` or similar).  In this
         mode, the ``name`` is used as the prefix of the full URL when
         generating a URL using :meth:`pyramid.request.Request.static_url`.
+        Furthermore, if a protocol-relative URL (e.g. ``//example.com/images``)
+        is used as the ``name`` argument, the generated URL will use the
+        protocol of the request (http or https, respectively).
+
         For example, if ``add_static_view`` is called like so:
 
         .. code-block:: python
@@ -1807,20 +1855,14 @@ class ViewsConfiguratorMixin(object):
 
         Subsequently, the URLs generated by
         :meth:`pyramid.request.Request.static_url` for that static view will
-        be prefixed with ``http://example.com/images``:
+        be prefixed with ``http://example.com/images`` (the external webserver
+        listening on ``example.com`` must be itself configured to respond
+        properly to such a request.):
 
         .. code-block:: python
 
            static_url('mypackage:images/logo.png', request)
 
-        When ``add_static_view`` is called with a ``name`` argument that is
-        the URL ``http://example.com/images``, subsequent calls to
-        :meth:`pyramid.request.Request.static_url` with paths that start with
-        the ``path`` argument passed to ``add_static_view`` will generate a
-        URL something like ``http://example.com/logo.png``.  The external
-        webserver listening on ``example.com`` must be itself configured to
-        respond properly to such a request.
-
         See :ref:`static_assets_section` for more information.
         """
         spec = self._make_spec(path)
@@ -1864,8 +1906,15 @@ class StaticURLInfo(object):
                     kw['subpath'] = subpath
                     return request.route_url(route_name, **kw)
                 else:
+                    app_url, scheme, host, port, qs, anchor = \
+                        parse_url_overrides(kw)
+                    parsed = url_parse(url)
+                    if not parsed.scheme:
+                        url = urlparse.urlunparse(parsed._replace(
+                            scheme=request.environ['wsgi.url_scheme']))
                     subpath = url_quote(subpath)
-                    return urljoin(url, subpath)
+                    result = urljoin(url, subpath)
+                    return result + qs + anchor
 
         raise ValueError('No static URL definition matching %s' % path)
 
@@ -1892,7 +1941,7 @@ class StaticURLInfo(object):
             # make sure it ends with a slash
             name = name + '/'
 
-        if url_parse(name)[0]:
+        if url_parse(name).netloc:
             # it's a URL
             # url, spec, route_name
             url = name
@@ -1907,27 +1956,16 @@ class StaticURLInfo(object):
 
             # Mutate extra to allow factory, etc to be passed through here.
             # Treat permission specially because we'd like to default to
-            # permissiveness (see docs of config.add_static_view).  We need
-            # to deal with both ``view_permission`` and ``permission``
-            # because ``permission`` is used in the docs for add_static_view,
-            # but ``add_route`` prefers ``view_permission``
-            permission = extra.pop('view_permission', None)
-            if permission is None:
-                permission = extra.pop('permission', None)
+            # permissiveness (see docs of config.add_static_view).
+            permission = extra.pop('permission', None)
             if permission is None:
                 permission = NO_PERMISSION_REQUIRED
 
-            context = extra.pop('view_context', None)
-            if context is None:
-                context = extra.pop('view_for', None)
+            context = extra.pop('context', None)
             if context is None:
                 context = extra.pop('for_', None)
 
-            renderer = extra.pop('view_renderer', None)
-            if renderer is None:
-                renderer = extra.pop('renderer', None)
-
-            attr = extra.pop('view_attr', None)
+            renderer = extra.pop('renderer', None)
 
             # register a route using the computed view, permission, and
             # pattern, plus any extras passed to us via add_static_view
@@ -1943,7 +1981,6 @@ class StaticURLInfo(object):
                 permission=permission,
                 context=context,
                 renderer=renderer,
-                attr=attr
                 )
 
         def register():
