@@ -7,13 +7,13 @@ single HTTP status code.  Each class is a subclass of the
 :class:`~HTTPException`.  Each exception class is also a :term:`response`
 object.
 
-Each exception class has a status code according to `RFC 2068
-<http://www.ietf.org/rfc/rfc2068.txt>`_: codes with 100-300 are not really
-errors; 400s are client errors, and 500s are server errors.
+Each exception class has a status code according to :rfc:`2068`:
+codes with 100-300 are not really errors; 400s are client errors,
+and 500s are server errors.
 
 Exception
   HTTPException
-    HTTPOk
+    HTTPSuccessful
       * 200 - HTTPOk
       * 201 - HTTPCreated
       * 202 - HTTPAccepted
@@ -28,7 +28,6 @@ Exception
       * 303 - HTTPSeeOther
       * 304 - HTTPNotModified
       * 305 - HTTPUseProxy
-      * 306 - Unused (not implemented, obviously)
       * 307 - HTTPTemporaryRedirect
     HTTPError
       HTTPClientError
@@ -307,23 +306,30 @@ class HTTPRedirection(HTTPException):
     condition.
     """
 
-class HTTPOk(HTTPException):
+class HTTPSuccessful(HTTPException):
     """
     Base class for exceptions with status codes in the 200s (successful
     responses)
+    """
+
+############################################################
+## 2xx success
+############################################################
+
+class HTTPOk(HTTPSuccessful):
+    """
+    subclass of :class:`~HTTPSuccessful`
+
+    Indicates that the request has succeeded.
     
     code: 200, title: OK
     """
     code = 200
     title = 'OK'
 
-############################################################
-## 2xx success
-############################################################
-
-class HTTPCreated(HTTPOk):
+class HTTPCreated(HTTPSuccessful):
     """
-    subclass of :class:`~HTTPOk`
+    subclass of :class:`~HTTPSuccessful`
 
     This indicates that request has been fulfilled and resulted in a new
     resource being created.
@@ -333,9 +339,9 @@ class HTTPCreated(HTTPOk):
     code = 201
     title = 'Created'
 
-class HTTPAccepted(HTTPOk):
+class HTTPAccepted(HTTPSuccessful):
     """
-    subclass of :class:`~HTTPOk`
+    subclass of :class:`~HTTPSuccessful`
 
     This indicates that the request has been accepted for processing, but the
     processing has not been completed.
@@ -346,9 +352,9 @@ class HTTPAccepted(HTTPOk):
     title = 'Accepted'
     explanation = 'The request is accepted for processing.'
 
-class HTTPNonAuthoritativeInformation(HTTPOk):
+class HTTPNonAuthoritativeInformation(HTTPSuccessful):
     """
-    subclass of :class:`~HTTPOk`
+    subclass of :class:`~HTTPSuccessful`
 
     This indicates that the returned metainformation in the entity-header is
     not the definitive set as available from the origin server, but is
@@ -359,9 +365,9 @@ class HTTPNonAuthoritativeInformation(HTTPOk):
     code = 203
     title = 'Non-Authoritative Information'
 
-class HTTPNoContent(HTTPOk):
+class HTTPNoContent(HTTPSuccessful):
     """
-    subclass of :class:`~HTTPOk`
+    subclass of :class:`~HTTPSuccessful`
 
     This indicates that the server has fulfilled the request but does
     not need to return an entity-body, and might want to return updated
@@ -373,9 +379,9 @@ class HTTPNoContent(HTTPOk):
     title = 'No Content'
     empty_body = True
 
-class HTTPResetContent(HTTPOk):
+class HTTPResetContent(HTTPSuccessful):
     """
-    subclass of :class:`~HTTPOk`
+    subclass of :class:`~HTTPSuccessful`
 
     This indicates that the server has fulfilled the request and
     the user agent SHOULD reset the document view which caused the
@@ -387,9 +393,9 @@ class HTTPResetContent(HTTPOk):
     title = 'Reset Content'
     empty_body = True
 
-class HTTPPartialContent(HTTPOk):
+class HTTPPartialContent(HTTPSuccessful):
     """
-    subclass of :class:`~HTTPOk`
+    subclass of :class:`~HTTPSuccessful`
 
     This indicates that the server has fulfilled the partial GET
     request for the resource.
@@ -559,6 +565,14 @@ class HTTPClientError(HTTPError):
                    'it is either malformed or otherwise incorrect.')
 
 class HTTPBadRequest(HTTPClientError):
+    """
+    subclass of :class:`~HTTPClientError`
+
+    This indicates that the body or headers failed validity checks,
+    preventing the server from being able to continue processing.
+
+    code: 400, title: Bad Request
+    """
     pass
 
 class HTTPUnauthorized(HTTPClientError):
@@ -646,8 +660,8 @@ class HTTPNotFound(HTTPClientError):
     code: 404, title: Not Found
 
     Raise this exception within :term:`view` code to immediately
-    return the :term:`Not Found view` to the invoking user.  Usually
-    this is a basic ``404`` page, but the Not Found view can be
+    return the :term:`Not Found View` to the invoking user.  Usually
+    this is a basic ``404`` page, but the Not Found View can be
     customized as necessary.  See :ref:`changing_the_notfound_view`.
 
     This exception's constructor accepts a ``detail`` argument
