@@ -57,9 +57,9 @@ class IApplicationCreated(Interface):
 IWSGIApplicationCreatedEvent = IApplicationCreated # b /c
 
 class IResponse(Interface):
-    """ Represents a WSGI response using the WebOb response interface.  Some
-    attribute and method documentation of this interface references `RFC 2616
-    <http://www.w3.org/Protocols/rfc2616/>`_.
+    """ Represents a WSGI response using the WebOb response interface.
+    Some attribute and method documentation of this interface references
+    :rfc:`2616`.
 
     This interface is most famously implemented by
     :class:`pyramid.response.Response` and the HTTP exception classes in
@@ -361,15 +361,37 @@ class IBeforeRender(IDict):
       def add_global(event):
           event['mykey'] = 'foo'
 
-    See also :ref:`beforerender_event`.
+    .. seealso::
+
+        See also :ref:`beforerender_event`.
     """
     rendering_val = Attribute('The value returned by a view or passed to a '
                               '``render`` method for this rendering. '
                               'This feature is new in Pyramid 1.2.')
 
+class IRendererInfo(Interface):
+    """ An object implementing this interface is passed to every
+    :term:`renderer factory` constructor as its only argument (conventionally
+    named ``info``)"""
+    name = Attribute('The value passed by the user as the renderer name')
+    package = Attribute('The "current package" when the renderer '
+                        'configuration statement was found')
+    type = Attribute('The renderer type name')
+    registry = Attribute('The "current" application registry when the '
+                         'renderer was created')
+    settings = Attribute('The deployment settings dictionary related '
+                         'to the current application')
+
+class IRendererFactory(Interface):
+    def __call__(info):
+        """ Return an object that implements
+        :class:`pyramid.interfaces.IRenderer`. ``info`` is an
+        object that implements :class:`pyramid.interfaces.IRendererInfo`.
+        """
+
 class IRenderer(Interface):
     def __call__(value, system):
-        """ Call a the renderer implementation with the result of the
+        """ Call the renderer with the result of the
         view (``value``) passed in and return a result (a string or
         unicode object useful as a response body).  Values computed by
         the system are passed by the system in the ``system``
@@ -387,6 +409,13 @@ class ITemplateRenderer(IRenderer):
         accepts arbitrary keyword arguments and returns a string or
         unicode object """
 
+deprecated(
+    'ITemplateRenderer',
+    'As of Pyramid 1.5 the, "pyramid.interfaces.ITemplateRenderer" interface '
+    'is scheduled to be removed. It was used by the Mako and Chameleon '
+    'renderers which have been split into their own packages.'
+    )
+
 class IViewMapper(Interface):
     def __call__(self, object):
         """ Provided with an arbitrary object (a function, class, or
@@ -460,7 +489,7 @@ class IAuthorizationPolicy(Interface):
 class IMultiDict(IDict): # docs-only interface
     """
     An ordered dictionary that can have multiple values for each key. A
-    multidict adds the methods ``getall``, ``getone``, ``mixed``, ``extend``
+    multidict adds the methods ``getall``, ``getone``, ``mixed``, ``extend``,
     ``add``, and ``dict_of_lists`` to the normal dictionary interface.  A
     multidict data structure is used as ``request.POST``, ``request.GET``,
     and ``request.params`` within an :app:`Pyramid` application.
@@ -611,26 +640,13 @@ class ITraverser(Interface):
 
 ITraverserFactory = ITraverser # b / c for 1.0 code
 
-class IRendererFactory(Interface):
-    def __call__(info):
-        """ Return an object that implements ``IRenderer``.  ``info`` is an
-        object that implement ``IRendererInfo``.  """
-
-class IRendererGlobalsFactory(Interface):
-    def __call__(system_values):
-        """ Return a dictionary of global renderer values (aka
-        top-level template names).  The ``system_values`` value passed
-        in will be a dictionary that includes at least a ``request``
-        key, indicating the current request, and the value
-        ``renderer_name``, which will be the name of the renderer in
-        use."""
-
 class IViewPermission(Interface):
     def __call__(context, request):
-        """ Return True if the permission allows, return False if it denies. """
+        """ Return True if the permission allows, return False if it denies.
+        """
 
 class IRouter(Interface):
-    """WSGI application which routes requests to 'view' code based on
+    """ WSGI application which routes requests to 'view' code based on
     a view registry."""
     registry = Attribute(
         """Component architecture registry local to this application.""")
@@ -692,6 +708,7 @@ class IRoute(Interface):
     pregenerator = Attribute('This attribute should either be ``None`` or '
                              'a callable object implementing the '
                              '``IRoutePregenerator`` interface')
+        
     def match(path):
         """
         If the ``path`` passed to this function can be matched by the
@@ -738,16 +755,24 @@ class IRoutesMapper(Interface):
         matched.  Static routes will not be considered for matching.  """
 
 class IResourceURL(Interface):
-    virtual_path = Attribute('The virtual url path of the resource.')
-    physical_path = Attribute('The physical url path of the resource.')
+    virtual_path = Attribute(
+        'The virtual url path of the resource as a string.'
+        )
+    physical_path = Attribute(
+        'The physical url path of the resource as a string.'
+        )
+    virtual_path_tuple = Attribute(
+        'The virtual url path of the resource as a tuple.  (New in 1.5)'
+        )
+    physical_path_tuple = Attribute(
+        'The physical url path of the resource as a tuple. (New in 1.5)'
+        )
 
 class IContextURL(IResourceURL):
-    """ An adapter which deals with URLs related to a context.
-
-    ..warning::
-
-      This interface is deprecated as of Pyramid 1.3 with the introduction of
-      IResourceURL.
+    """
+    .. deprecated:: 1.3
+        An adapter which deals with URLs related to a context.  Use
+        :class:`pyramid.interfaces.IResourceURL` instead.
     """
     # this class subclasses IResourceURL because request.resource_url looks
     # for IResourceURL via queryAdapter.  queryAdapter will find a deprecated
@@ -762,15 +787,15 @@ class IContextURL(IResourceURL):
     #
     # class Fudge(object):
     #     def __init__(self, one, two):
-    #         print one, two
+    #         print(one, two)
     # class Another(object):
     #     def __init__(self, one, two):
-    #         print one, two
+    #         print(one, two)
     # ob = object()
     # r.registerAdapter(Fudge, (Interface, Interface), IContextURL)
-    # print r.queryMultiAdapter((ob, ob), IResourceURL)
+    # print(r.queryMultiAdapter((ob, ob), IResourceURL))
     # r.registerAdapter(Another, (Interface, Interface), IResourceURL)
-    # print r.queryMultiAdapter((ob, ob), IResourceURL)
+    # print(r.queryMultiAdapter((ob, ob), IResourceURL))
     #
     # prints
     #
@@ -792,7 +817,7 @@ deprecated(
     'scheduled to be removed.   Use the '
     '"pyramid.config.Configurator.add_resource_url_adapter" method to register '
     'a class that implements "pyramid.interfaces.IResourceURL" instead. '
-    'See the "What\'s new In Pyramid 1.3" document for a further description.'
+    'See the "What\'s new In Pyramid 1.3" document for more details.'
     )
 
 class IPEP302Loader(Interface):
@@ -844,19 +869,6 @@ class IPackageOverrides(IPEP302Loader):
 # traversalwrapper)
 VH_ROOT_KEY = 'HTTP_X_VHM_ROOT'
 
-class IChameleonLookup(Interface):
-    translate = Attribute('IChameleonTranslate object')
-    debug = Attribute('The ``debug_templates`` setting for this application')
-    auto_reload = Attribute('The ``reload_templates`` setting for this app')
-    def __call__(self, info):
-        """ Return an ITemplateRenderer based on IRendererInfo ``info`` """
-
-class IChameleonTranslate(Interface):
-    """ Internal interface representing a chameleon translate function """
-    def __call__(msgid, domain=None, mapping=None, context=None,
-                 target_language=None, default=None):
-        """ Translate a mess of arguments to a Unicode object """
-
 class ILocalizer(Interface):
     """ Localizer for a specific language """
 
@@ -917,7 +929,7 @@ class ISession(IDict):
         by ``queue``.  An alternate flash message queue can used by passing
         an optional ``queue``, which must be a string.  If
         ``allow_duplicate`` is false, if the ``msg`` already exists in the
-        queue, it will not be readded."""
+        queue, it will not be re-added."""
 
     def pop_flash(queue=''):
         """ Pop a queue from the flash storage.  The queue is removed from
@@ -945,20 +957,6 @@ class ISession(IDict):
         returned.
         """
 
-class IRendererInfo(Interface):
-    """ An object implementing this interface is passed to every
-    :term:`renderer factory` constructor as its only argument (conventionally
-    named ``info``)"""
-    name = Attribute('The value passed by the user as the renderer name')
-    package = Attribute('The "current package" when the renderer '
-                        'configuration statement was found')
-    type = Attribute('The renderer type name')
-    registry = Attribute('The "current" application registry when the '
-                         'renderer was created')
-    settings = Attribute('The deployment settings dictionary related '
-                         'to the current application')
-
-
 class IIntrospector(Interface):
     def get(category_name, discriminator, default=None):
         """ Get the IIntrospectable related to the category_name and the
