@@ -1,8 +1,5 @@
 import json
 import os
-import re
-import pkg_resources
-import threading
 
 from zope.interface import (
     implementer,
@@ -11,18 +8,12 @@ from zope.interface import (
 from zope.interface.registry import Components
 
 from pyramid.interfaces import (
-    IChameleonLookup,
-    IChameleonTranslate,
     IJSONAdapter,
-    IRendererGlobalsFactory,
     IRendererFactory,
     IResponseFactory,
-    ITemplateRenderer,
     IRendererInfo,
     )
 
-from pyramid.asset import asset_spec_from_abspath
-
 from pyramid.compat import (
     string_types,
     text_type,
@@ -32,10 +23,7 @@ from pyramid.decorator import reify
 
 from pyramid.events import BeforeRender
 
-from pyramid.path import (
-    caller_package,
-    package_path,
-    )
+from pyramid.path import caller_package
 
 from pyramid.response import Response
 from pyramid.threadlocal import get_current_registry
@@ -43,23 +31,23 @@ from pyramid.threadlocal import get_current_registry
 # API
 
 def render(renderer_name, value, request=None, package=None):
-    """ Using the renderer specified as ``renderer_name`` (a template
-    or a static renderer) render the value (or set of values) present
+    """ Using the renderer ``renderer_name`` (a template
+    or a static renderer), render the value (or set of values) present
     in ``value``. Return the result of the renderer's ``__call__``
     method (usually a string or Unicode).
 
-    If the renderer name refers to a file on disk (such as when the
-    renderer is a template), it's usually best to supply the name as a
+    If the ``renderer_name`` refers to a file on disk, such as when the
+    renderer is a template, it's usually best to supply the name as an
     :term:`asset specification`
     (e.g. ``packagename:path/to/template.pt``).
 
     You may supply a relative asset spec as ``renderer_name``.  If
     the ``package`` argument is supplied, a relative renderer path
     will be converted to an absolute asset specification by
-    combining the package supplied as ``package`` with the relative
-    asset specification supplied as ``renderer_name``.  If you do
-    not supply a ``package`` (or ``package`` is ``None``) the package
-    name of the *caller* of this function will be used as the package.
+    combining the package ``package`` with the relative
+    asset specification ``renderer_name``.  If ``package``
+    is ``None`` (the default), the package name of the *caller* of
+    this function will be used as the package.
 
     The ``value`` provided will be supplied as the input to the
     renderer.  Usually, for template renderings, this should be a
@@ -70,7 +58,7 @@ def render(renderer_name, value, request=None, package=None):
     top-level system names, such as ``request``, ``context``,
     ``renderer_name``, and ``view``.  See :ref:`renderer_system_values` for
     the full list.  If :term:`renderer globals` have been specified, these
-    will also be used to agument the value.
+    will also be used to augment the value.
 
     Supply a ``request`` parameter in order to provide the renderer
     with the most correct 'system' values (``request`` and ``context``
@@ -85,11 +73,27 @@ def render(renderer_name, value, request=None, package=None):
         package = caller_package()
     helper = RendererHelper(name=renderer_name, package=package,
                             registry=registry)
-    return helper.render(value, None, request=request)
+
+    saved_response = None
+    # save the current response, preventing the renderer from affecting it
+    attrs = request.__dict__ if request is not None else {}
+    if 'response' in attrs:
+        saved_response = attrs['response']
+        del attrs['response']
+
+    result = helper.render(value, None, request=request)
+
+    # restore the original response, overwriting any changes
+    if saved_response is not None:
+        attrs['response'] = saved_response
+    elif 'response' in attrs:
+        del attrs['response']
+
+    return result
 
 def render_to_response(renderer_name, value, request=None, package=None):
-    """ Using the renderer specified as ``renderer_name`` (a template
-    or a static renderer) render the value (or set of values) using
+    """ Using the renderer ``renderer_name`` (a template
+    or a static renderer), render the value (or set of values) using
     the result of the renderer's ``__call__`` method (usually a string
     or Unicode) as the response body.
 
@@ -100,8 +104,8 @@ def render_to_response(renderer_name, value, request=None, package=None):
     You may supply a relative asset spec as ``renderer_name``.  If
     the ``package`` argument is supplied, a relative renderer name
     will be converted to an absolute asset specification by
-    combining the package supplied as ``package`` with the relative
-    asset specification supplied as ``renderer_name``.  If you do
+    combining the package ``package`` with the relative
+    asset specification ``renderer_name``.  If you do
     not supply a ``package`` (or ``package`` is ``None``) the package
     name of the *caller* of this function will be used as the package.
 
@@ -114,7 +118,7 @@ def render_to_response(renderer_name, value, request=None, package=None):
     top-level system names, such as ``request``, ``context``,
     ``renderer_name``, and ``view``.  See :ref:`renderer_system_values` for
     the full list.  If :term:`renderer globals` have been specified, these
-    will also be used to agument the value.
+    will also be used to argument the value.
 
     Supply a ``request`` parameter in order to provide the renderer
     with the most correct 'system' values (``request`` and ``context``
@@ -134,16 +138,15 @@ def render_to_response(renderer_name, value, request=None, package=None):
     return helper.render_to_response(value, None, request=request)
 
 def get_renderer(renderer_name, package=None):
-    """ Return the renderer object for the renderer named as
-    ``renderer_name``.
+    """ Return the renderer object for the renderer ``renderer_name``.
 
     You may supply a relative asset spec as ``renderer_name``.  If
     the ``package`` argument is supplied, a relative renderer name
     will be converted to an absolute asset specification by
-    combining the package supplied as ``package`` with the relative
-    asset specification supplied as ``renderer_name``.  If you do
-    not supply a ``package`` (or ``package`` is ``None``) the package
-    name of the *caller* of this function will be used as the package.
+    combining the package ``package`` with the relative
+    asset specification ``renderer_name``.  If ``package`` is ``None``
+    (the default), the package name of the *caller* of this function
+    will be used as the package.
     """
     if package is None:
         package = caller_package()
@@ -198,17 +201,21 @@ class JSON(object):
     adapters with the renderer.  See
     :ref:`json_serializing_custom_objects` for more information.
 
-    The default serializer uses ``json.JSONEncoder``. A different
-    serializer can be specified via the ``serializer`` argument.
-    Custom serializers should accept the object, a callback
-    ``default``, and any extra ``kw`` keyword argments passed during
-    renderer construction.
-
     .. note::
 
-       This feature is new in Pyramid 1.4. Prior to 1.4 there was
-       no public API for supplying options to the underlying
-       serializer without defining a custom renderer.
+        The default serializer uses ``json.JSONEncoder``. A different
+        serializer can be specified via the ``serializer`` argument.  Custom
+        serializers should accept the object, a callback ``default``, and any
+        extra ``kw`` keyword arguments passed during renderer construction.
+        This feature isn't widely used but it can be used to replace the
+        stock JSON serializer with, say, simplejson.  If all you want to
+        do, however, is serialize custom objects, you should use the method
+        explained in :ref:`json_serializing_custom_objects` instead
+        of replacing the serializer.
+
+    .. versionadded:: 1.4
+       Prior to this version, there was no public API for supplying options
+       to the underlying serializer without defining a custom renderer.
     """
 
     def __init__(self, serializer=json.dumps, adapters=(), **kw):
@@ -303,8 +310,8 @@ class JSONP(JSON):
        config = Configurator()
        config.add_renderer('jsonp', JSONP(param_name='callback', indent=4))
     
-    .. note:: The ability of this class to accept a ``**kw`` in its
-       constructor is new as of Pyramid 1.4.
+    .. versionchanged:: 1.4
+       The ability of this class to accept a ``**kw`` in its constructor.
 
     The arguments passed to this class' constructor mean the same thing as
     the arguments passed to :class:`pyramid.renderers.JSON` (including
@@ -332,9 +339,11 @@ class JSONP(JSON):
     - If there is no callback parameter in the request's query string, the
       renderer will return a 'plain' JSON response.
 
-    .. note:: This feature is new in Pyramid 1.1.
+    .. versionadded:: 1.1
 
-    See also: :ref:`jsonp_renderer`.
+    .. seealso::
+
+        See also :ref:`jsonp_renderer`.
     """
 
     def __init__(self, param_name='callback', **kw):
@@ -356,135 +365,13 @@ class JSONP(JSON):
                 body = val
             else:
                 ct = 'application/javascript'
-                body = '%s(%s)' % (callback, val)
+                body = '%s(%s);' % (callback, val)
             response = request.response
             if response.content_type == response.default_content_type:
                 response.content_type = ct
             return body
         return _render
 
-# utility functions, not API
-
-@implementer(IChameleonLookup)
-class ChameleonRendererLookup(object):
-    spec_re = re.compile(
-        r'(?P<asset>[\w_.:/-]+)'
-        r'(?:\#(?P<defname>[\w_]+))?'
-        r'(\.(?P<ext>.*))'
-        )
-
-    def __init__(self, impl, registry):
-        self.impl = impl
-        self.registry = registry
-        self.lock = threading.Lock()
-
-    def get_spec(self, name, package):
-        if not package:
-            # if there's no package, we can't do any conversion
-            return name
-
-        spec = name
-        isabspath = os.path.isabs(name)
-        colon_in_name = ':' in name
-        isabsspec = colon_in_name and (not isabspath)
-        isrelspec = (not isabsspec) and (not isabspath)
-
-        # if it's already an absolute spec, we don't need to do anything,
-        # but if it's a relative spec or an absolute path, we need to try
-        # to convert it to an absolute spec
-
-        if isrelspec:
-            # convert relative asset spec to absolute asset spec
-            pp = package_path(package)
-            spec = os.path.join(pp, spec)
-            spec = asset_spec_from_abspath(spec, package)
-
-        elif isabspath:
-            # convert absolute path to absolute asset spec
-            spec = asset_spec_from_abspath(spec, package)
-
-        return spec
-
-    @property # wait until completely necessary to look up translator
-    def translate(self):
-        return self.registry.queryUtility(IChameleonTranslate)
-
-    @property # wait until completely necessary to look up debug_templates
-    def debug(self):
-        settings = self.registry.settings
-        if settings is None:
-            return False
-        return settings.get('debug_templates', False)
-
-    @property # wait until completely necessary to look up reload_templates
-    def auto_reload(self):
-        settings = self.registry.settings
-        if settings is None:
-            return False
-        return settings.get('reload_templates', False)
-
-    def _crack_spec(self, spec):
-        asset, macro, ext = self.spec_re.match(spec).group(
-            'asset', 'defname', 'ext'
-            )
-        return asset, macro, ext
-    
-    def __call__(self, info):
-        spec = self.get_spec(info.name, info.package)
-        registry = info.registry
-
-        if os.path.isabs(spec):
-            # 'spec' is an absolute filename
-            if not os.path.exists(spec):
-                raise ValueError('Missing template file: %s' % spec)
-            renderer = registry.queryUtility(ITemplateRenderer, name=spec)
-            if renderer is None:
-                renderer = self.impl(spec, self, macro=None)
-                # cache the template
-                with self.lock:
-                    registry.registerUtility(renderer,
-                                             ITemplateRenderer, name=spec)
-        else:
-            # spec is a package:relpath asset spec
-            renderer = registry.queryUtility(ITemplateRenderer, name=spec)
-            if renderer is None:
-                asset, macro, ext = self._crack_spec(spec)
-                spec_without_macro = '%s.%s' % (asset, ext)
-                try:
-                    package_name, filename = spec_without_macro.split(':', 1)
-                except ValueError: # pragma: no cover
-                    # somehow we were passed a relative pathname; this
-                    # should die
-                    package_name = caller_package(4).__name__
-                    filename = spec_without_macro
-                abspath = pkg_resources.resource_filename(package_name,
-                                                          filename)
-                if not pkg_resources.resource_exists(package_name, filename):
-                    raise ValueError(
-                        'Missing template asset: %s (%s)' % (
-                            spec_without_macro, abspath)
-                        )
-                renderer = self.impl(abspath, self, macro=macro)
-                settings = info.settings
-                if not settings.get('reload_assets'):
-                    # cache the template
-                    with self.lock:
-                        registry.registerUtility(renderer, ITemplateRenderer,
-                                                 name=spec)
-
-        return renderer
-
-registry_lock = threading.Lock()
-
-def template_renderer_factory(info, impl, lock=registry_lock):
-    registry = info.registry
-    lookup = registry.queryUtility(IChameleonLookup, name=info.type)
-    if lookup is None:
-        lookup = ChameleonRendererLookup(impl, registry)
-        with lock:
-            registry.registerUtility(lookup, IChameleonLookup, name=info.type)
-    return lookup(info)
-
 @implementer(IRendererInfo)
 class RendererHelper(object):
     def __init__(self, name=None, package=None, registry=None):
@@ -545,13 +432,6 @@ class RendererHelper(object):
         system_values = BeforeRender(system_values, value)
 
         registry = self.registry
-        globals_factory = registry.queryUtility(IRendererGlobalsFactory)
-
-        if globals_factory is not None:
-            renderer_globals = globals_factory(system_values)
-            if renderer_globals:
-                system_values.update(renderer_globals)
-
         registry.notify(system_values)
 
         result = renderer(value, system_values)
@@ -579,26 +459,6 @@ class RendererHelper(object):
             else:
                 response.body = result
 
-        if request is not None:
-            # deprecated mechanism to set up request.response_* attrs, see
-            # pyramid.request.Request
-            attrs = request.__dict__
-            content_type = attrs.get('_response_content_type', None)
-            if content_type is not None:
-                response.content_type = content_type
-            headerlist = attrs.get('_response_headerlist', None)
-            if headerlist is not None:
-                for k, v in headerlist:
-                    response.headers.add(k, v)
-            status = attrs.get('_response_status', None)
-            if status is not None:
-                response.status = status
-            charset = attrs.get('_response_charset', None)
-            if charset is not None:
-                response.charset = charset
-            cache_for = attrs.get('_response_cache_for', None)
-            if cache_for is not None:
-                response.cache_expires = cache_for
         return response
 
     def clone(self, name=None, package=None, registry=None):
