@@ -1,7 +1,5 @@
 import json
 
-from zope.deprecation import deprecate
-from zope.deprecation.deprecation import deprecated
 from zope.interface import implementer
 from zope.interface.interface import InterfaceClass
 
@@ -15,183 +13,24 @@ from pyramid.interfaces import (
     )
 
 from pyramid.compat import (
-    iterkeys_,
-    itervalues_,
-    iteritems_,
     text_,
     bytes_,
     native_,
     )
 
 from pyramid.decorator import reify
+from pyramid.i18n import LocalizerRequestMixin
 from pyramid.response import Response
+from pyramid.security import (
+    AuthenticationAPIMixin,
+    AuthorizationAPIMixin,
+    )
 from pyramid.url import URLMethodsMixin
 from pyramid.util import InstancePropertyMixin
 
 class TemplateContext(object):
     pass
 
-class DeprecatedRequestMethodsMixin(object):
-
-    # b/c dict interface for "root factory" code that expects a bare
-    # environ.  Explicitly omitted dict methods: clear (unnecessary),
-    # copy (implemented by WebOb), fromkeys (unnecessary); deprecated
-    # as of Pyramid 1.1.
-
-    dictlike = ('Use of the request as a dict-like object is deprecated as '
-                'of Pyramid 1.1.  Use dict-like methods of "request.environ" '
-                'instead.')
-
-    @deprecate(dictlike)
-    def __contains__(self, k):
-        return self.environ.__contains__(k)
-
-    @deprecate(dictlike)
-    def __delitem__(self, k):
-        return self.environ.__delitem__(k)
-
-    @deprecate(dictlike)
-    def __getitem__(self, k):
-        return self.environ.__getitem__(k)
-
-    @deprecate(dictlike)
-    def __iter__(self):
-        return iter(self.environ)
-
-    @deprecate(dictlike)
-    def __setitem__(self, k, v):
-        self.environ[k] = v
-
-    @deprecate(dictlike)
-    def get(self, k, default=None):
-        return self.environ.get(k, default)
-
-    @deprecate(dictlike)
-    def has_key(self, k):
-        return k in self.environ
-
-    @deprecate(dictlike)
-    def items(self):
-        return self.environ.items()
-
-    @deprecate(dictlike)
-    def iteritems(self):
-        return iteritems_(self.environ)
-
-    @deprecate(dictlike)
-    def iterkeys(self):
-        return iterkeys_(self.environ)
-
-    @deprecate(dictlike)
-    def itervalues(self):
-        return itervalues_(self.environ)
-
-    @deprecate(dictlike)
-    def keys(self):
-        return self.environ.keys()
-
-    @deprecate(dictlike)
-    def pop(self, k):
-        return self.environ.pop(k)
-
-    @deprecate(dictlike)
-    def popitem(self):
-        return self.environ.popitem()
-
-    @deprecate(dictlike)
-    def setdefault(self, v, default):
-        return self.environ.setdefault(v, default)
-
-    @deprecate(dictlike)
-    def update(self, v, **kw):
-        return self.environ.update(v, **kw)
-
-    @deprecate(dictlike)
-    def values(self):
-        return self.environ.values()
-
-    # 1.0 deprecated bw compat code for using response_* values
-
-    rr_dep = ('Accessing and setting "request.response_%s" is '
-              'deprecated as of Pyramid 1.1; access or set '
-              '"request.response.%s" instead.')
-
-    # response_content_type
-    def _response_content_type_get(self):
-        return self._response_content_type
-    def _response_content_type_set(self, value):
-        self._response_content_type = value
-    def _response_content_type_del(self):
-        del self._response_content_type
-    response_content_type = property(_response_content_type_get,
-                                     _response_content_type_set,
-                                     _response_content_type_del)
-    response_content_type = deprecated(
-        response_content_type,
-        rr_dep % ('content_type', 'content_type'))
-
-    # response_headerlist
-    def _response_headerlist_get(self):
-        return self._response_headerlist
-    def _response_headerlist_set(self, value):
-        self._response_headerlist = value
-    def _response_headerlist_del(self):
-        del self._response_headerlist
-    response_headerlist = property(_response_headerlist_get,
-                                   _response_headerlist_set,
-                                   _response_headerlist_del)
-
-    hl_dep = ('Accessing and setting "request.response_headerlist" is '
-              'deprecated as of Pyramid 1.1; access the headerlist via '
-              '"request.response.headerlist" and extend headers via '
-              '"request.response.headerlist.extend(alist)" instead of '
-              '"request.response_headerlist = alist"')
-
-    response_headerlist = deprecated(response_headerlist, hl_dep)
-
-    # response_status
-    def _response_status_get(self):
-        return self._response_status
-    def _response_status_set(self, value):
-        self._response_status = value
-    def _response_status_del(self):
-        del self._response_status
-    response_status = property(_response_status_get,
-                               _response_status_set,
-                               _response_status_del)
-
-    response_status = deprecated(
-        response_status,
-        rr_dep % ('status', 'status'))
-
-    # response_charset
-    def _response_charset_get(self):
-        return self._response_charset
-    def _response_charset_set(self, value):
-        self._response_charset = value
-    def _response_charset_del(self):
-        del self._response_charset
-    response_charset = property(_response_charset_get,
-                                _response_charset_set,
-                                _response_charset_del)
-    response_charset = deprecated(
-        response_charset,
-        rr_dep % ('charset', 'charset'))
-
-    # response_cache_for
-    def _response_cache_for_get(self):
-        return self._response_cache_for
-    def _response_cache_for_set(self, value):
-        self._response_cache_for = value
-    def _response_cache_for_del(self):
-        del self._response_cache_for
-    response_cache_for = property(_response_cache_for_get,
-                                  _response_cache_for_set,
-                                  _response_cache_for_del)
-    response_cache_for = deprecated(
-        response_cache_for,
-        rr_dep % ('cache_for', 'cache_expires'))
-
 class CallbackMethodsMixin(object):
     response_callbacks = ()
     finished_callbacks = ()
@@ -220,14 +59,16 @@ class CallbackMethodsMixin(object):
         called if an exception happens in application code, or if the
         response object returned by :term:`view` code is invalid.
 
-        All response callbacks are called *after* the
-        :class:`pyramid.events.NewResponse` event is sent.
+        All response callbacks are called *after* the tweens and 
+        *before* the :class:`pyramid.events.NewResponse` event is sent.
 
         Errors raised by callbacks are not handled specially.  They
         will be propagated to the caller of the :app:`Pyramid`
         router application.
 
-        See also: :ref:`using_response_callbacks`.
+        .. seealso::
+
+            See also :ref:`using_response_callbacks`.
         """
 
         callbacks = self.response_callbacks
@@ -285,7 +126,9 @@ class CallbackMethodsMixin(object):
         They will be propagated to the caller of the :app:`Pyramid`
         router application.
 
-        See also: :ref:`using_finished_callbacks`.
+        .. seealso::
+
+            See also :ref:`using_finished_callbacks`.
         """
 
         callbacks = self.finished_callbacks
@@ -301,8 +144,15 @@ class CallbackMethodsMixin(object):
             callback(self)
 
 @implementer(IRequest)
-class Request(BaseRequest, DeprecatedRequestMethodsMixin, URLMethodsMixin,
-              CallbackMethodsMixin, InstancePropertyMixin):
+class Request(
+    BaseRequest,
+    URLMethodsMixin,
+    CallbackMethodsMixin,
+    InstancePropertyMixin,
+    LocalizerRequestMixin,
+    AuthenticationAPIMixin,
+    AuthorizationAPIMixin,
+    ):
     """
     A subclass of the :term:`WebOb` Request class.  An instance of
     this class is created by the :term:`router` and is provided to a
@@ -321,7 +171,7 @@ class Request(BaseRequest, DeprecatedRequestMethodsMixin, URLMethodsMixin,
     version number from which this documentation is autogenerated, but
     it will be the 'prevailing WebOb version' at the time of the
     release of this :app:`Pyramid` version.  See
-    http://pythonpaste.org/webob/ for further information.
+    http://webob.org/ for further information.
     """
     exception = None
     exc_info = None
@@ -354,8 +204,7 @@ class Request(BaseRequest, DeprecatedRequestMethodsMixin, URLMethodsMixin,
         """This attribute is actually a "reified" property which returns an
         instance of the :class:`pyramid.response.Response`. class.  The
         response object returned does not exist until this attribute is
-        accessed.  Once it is accessed, subsequent accesses will return the
-        same Response object.
+        accessed.  Subsequent accesses will return the same Response object.
 
         The ``request.response`` API is used by renderers.  A render obtains
         the response object it will return from a view that uses that renderer
@@ -384,6 +233,7 @@ class Request(BaseRequest, DeprecatedRequestMethodsMixin, URLMethodsMixin,
     def json_body(self):
         return json.loads(text_(self.body, self.charset))
 
+    
 def route_request_iface(name, bases=()):
     # zope.interface treats the __name__ as the __doc__ and changes __name__
     # to None for interfaces that contain spaces if you do not pass a
