@@ -12,7 +12,7 @@ class PyramidTemplate(Template):
      templates.
     """
     def pre(self, command, output_dir, vars):
-        """ Overrides :meth:`pyramid.scaffold.template.Template.pre`, adding
+        """ Overrides :meth:`pyramid.scaffolds.template.Template.pre`, adding
         several variables to the default variables list (including
         ``random_string``, and ``package_logger``).  It also prevents common
         misnamings (such as naming a package "site" or naming a package
@@ -31,7 +31,7 @@ class PyramidTemplate(Template):
         return Template.pre(self, command, output_dir, vars)
 
     def post(self, command, output_dir, vars): # pragma: no cover
-        """ Overrides :meth:`pyramid.scaffold.template.Template.post`, to
+        """ Overrides :meth:`pyramid.scaffolds.template.Template.post`, to
         print "Welcome to Pyramid.  Sorry for the convenience." after a
         successful scaffolding rendering."""
 
