@@ -21,12 +21,15 @@ from pyramid.compat import (
 
 from pyramid.config import Configurator
 from pyramid.decorator import reify
+from pyramid.path import caller_package
 from pyramid.response import Response
 from pyramid.registry import Registry
 
 from pyramid.security import (
     Authenticated,
     Everyone,
+    AuthenticationAPIMixin,
+    AuthorizationAPIMixin,
     )
 
 from pyramid.threadlocal import (
@@ -34,11 +37,8 @@ from pyramid.threadlocal import (
     manager,
     )
 
-from pyramid.request import (
-    DeprecatedRequestMethodsMixin,
-    CallbackMethodsMixin,
-    )
-
+from pyramid.i18n import LocalizerRequestMixin
+from pyramid.request import CallbackMethodsMixin
 from pyramid.url import URLMethodsMixin
 from pyramid.util import InstancePropertyMixin
 
@@ -137,7 +137,7 @@ class DummyTemplateRenderer(object):
     def assert_(self, **kw):
         """ Accept an arbitrary set of assertion key/value pairs.  For
         each assertion key/value pair assert that the renderer
-        (eg. :func:`pyramid.renderer.render_to_response`)
+        (eg. :func:`pyramid.renderers.render_to_response`)
         received the key with a value that equals the asserted
         value. If the renderer did not receive the key at all, or the
         value received by the renderer doesn't match the assertion
@@ -222,6 +222,8 @@ class DummyResource:
     def __nonzero__(self):
         return True
 
+    __bool__ = __nonzero__
+
     def __len__(self):
         return len(self.subs)
 
@@ -281,10 +283,15 @@ class DummySession(dict):
             token = self.new_csrf_token()
         return token
 
-        
 @implementer(IRequest)
-class DummyRequest(DeprecatedRequestMethodsMixin, URLMethodsMixin,
-                   CallbackMethodsMixin, InstancePropertyMixin):
+class DummyRequest(
+    URLMethodsMixin,
+    CallbackMethodsMixin,
+    InstancePropertyMixin,
+    LocalizerRequestMixin,
+    AuthenticationAPIMixin,
+    AuthorizationAPIMixin,
+    ):
     """ A DummyRequest object (incompletely) imitates a :term:`request` object.
 
     The ``params``, ``environ``, ``headers``, ``path``, and
@@ -314,6 +321,7 @@ class DummyRequest(DeprecatedRequestMethodsMixin, URLMethodsMixin,
     method = 'GET'
     application_url = 'http://example.com'
     host = 'example.com:80'
+    domain = 'example.com'
     content_length = 0
     query_string = ''
     charset = 'UTF-8'
@@ -381,7 +389,7 @@ class DummyRequest(DeprecatedRequestMethodsMixin, URLMethodsMixin,
 have_zca = True
 
 def setUp(registry=None, request=None, hook_zca=True, autocommit=True,
-          settings=None):
+          settings=None, package=None):
     """
     Set :app:`Pyramid` registry and request thread locals for the
     duration of a single unit test.
@@ -409,7 +417,7 @@ def setUp(registry=None, request=None, hook_zca=True, autocommit=True,
     suitable testing analogue.
 
     After ``setUp`` is finished, the registry returned by the
-    :func:`pyramid.threadlocal.get_current_request` function will
+    :func:`pyramid.threadlocal.get_current_registry` function will
     be the passed (or constructed) registry until
     :func:`pyramid.testing.tearDown` is called (or
     :func:`pyramid.testing.setUp` is called again) .
@@ -425,9 +433,15 @@ def setUp(registry=None, request=None, hook_zca=True, autocommit=True,
     :mod:`zope.component` package cannot be imported, or if
     ``hook_zca`` is ``False``, the hook will not be set.
 
-    If ``settings`` is not None, it must be a dictionary representing the
+    If ``settings`` is not ``None``, it must be a dictionary representing the
     values passed to a Configurator as its ``settings=`` argument.
 
+    If ``package`` is ``None`` it will be set to the caller's package. The
+    ``package`` setting in the :class:`pyramid.config.Configurator` will
+    affect any relative imports made via
+    :meth:`pyramid.config.Configurator.include` or
+    :meth:`pyramid.config.Configurator.maybe_dotted`.
+
     This function returns an instance of the
     :class:`pyramid.config.Configurator` class, which can be
     used for further configuration to set up an environment suitable
@@ -440,7 +454,10 @@ def setUp(registry=None, request=None, hook_zca=True, autocommit=True,
     manager.clear()
     if registry is None:
         registry = Registry('testing')
-    config = Configurator(registry=registry, autocommit=autocommit)
+    if package is None:
+        package = caller_package()
+    config = Configurator(registry=registry, autocommit=autocommit,
+                          package=package)
     if settings is None:
         settings = {}
     if getattr(registry, 'settings', None) is None:
@@ -451,18 +468,7 @@ def setUp(registry=None, request=None, hook_zca=True, autocommit=True,
         # someone may be passing us an esoteric "dummy" registry, and
         # the below won't succeed if it doesn't have a registerUtility
         # method.
-        from pyramid.config import DEFAULT_RENDERERS
-        for name, renderer in DEFAULT_RENDERERS:
-            # Cause the default renderers to be registered because
-            # in-the-wild test code relies on being able to call
-            # e.g. ``pyramid.chameleon_zpt.render_template``
-            # without registering a .pt renderer, expecting the "real"
-            # template to be rendered.  This is a holdover from when
-            # individual template system renderers weren't indirected
-            # by the ``pyramid.renderers`` machinery, and
-            # ``render_template`` and friends went behind the back of
-            # any existing renderer factory lookup system.
-            config.add_renderer(name, renderer)
+        config.add_default_renderers()
         config.add_default_view_predicates()
         config.add_default_route_predicates()
     config.commit()
@@ -476,15 +482,15 @@ def setUp(registry=None, request=None, hook_zca=True, autocommit=True,
     return config
 
 def tearDown(unhook_zca=True):
-    """Undo the effects :func:`pyramid.testing.setUp`.  Use this
+    """Undo the effects of :func:`pyramid.testing.setUp`.  Use this
     function in the ``tearDown`` method of a unit test that uses
     :func:`pyramid.testing.setUp` in its ``setUp`` method.
 
     If the ``unhook_zca`` argument is ``True`` (the default), call
     :func:`zope.component.getSiteManager.reset`.  This undoes the
-    action of :func:`pyramid.testing.setUp` called with the
+    action of :func:`pyramid.testing.setUp` when called with the
     argument ``hook_zca=True``.  If :mod:`zope.component` cannot be
-    imported, ignore the argument.
+    imported, ``unhook_zca`` is set to ``False``.
     """
     global have_zca
     if unhook_zca and have_zca:
@@ -508,8 +514,11 @@ def tearDown(unhook_zca=True):
                 pass
 
 def cleanUp(*arg, **kw):
-    """ :func:`pyramid.testing.cleanUp` is an alias for
-    :func:`pyramid.testing.setUp`. """
+    """ An alias for :func:`pyramid.testing.setUp`. """
+    package = kw.get('package', None)
+    if package is None:
+        package = caller_package()
+        kw['package'] = package
     return setUp(*arg, **kw)
 
 class DummyRendererFactory(object):
@@ -591,10 +600,10 @@ def testConfig(registry=None,
         settings=None):
     """Returns a context manager for test set up.
 
-    This context manager calls :func:`pyramid.testing.testSetup` when
+    This context manager calls :func:`pyramid.testing.setUp` when
     entering and :func:`pyramid.testing.tearDown` when exiting.
 
-    All arguments are passed directly to :func:`pyramid.testing.testSetup`.
+    All arguments are passed directly to :func:`pyramid.testing.setUp`.
     If the ZCA is hooked, it will always be un-hooked in tearDown.
 
     This context manager allows you to write test code like this:
