@@ -42,13 +42,10 @@ class TestI18NConfiguratorMixin(unittest.TestCase):
 
     def test_add_translation_dirs_no_specs(self):
         from pyramid.interfaces import ITranslationDirectories
-        from pyramid.interfaces import IChameleonTranslate
         config = self._makeOne()
         config.add_translation_dirs()
         self.assertEqual(config.registry.queryUtility(ITranslationDirectories),
                          None)
-        self.assertEqual(config.registry.queryUtility(IChameleonTranslate),
-                         None)
 
     def test_add_translation_dirs_asset_spec(self):
         from pyramid.interfaces import ITranslationDirectories
@@ -83,19 +80,6 @@ class TestI18NConfiguratorMixin(unittest.TestCase):
         self.assertEqual(config.registry.getUtility(ITranslationDirectories),
                          [locale3, locale, locale2])
 
-    def test_add_translation_dirs_registers_chameleon_translate(self):
-        from pyramid.interfaces import IChameleonTranslate
-        from pyramid.threadlocal import manager
-        request = DummyRequest()
-        config = self._makeOne(autocommit=True)
-        manager.push({'request':request, 'registry':config.registry})
-        try:
-            config.add_translation_dirs('pyramid.tests.pkgs.localeapp:locale')
-            translate = config.registry.getUtility(IChameleonTranslate)
-            self.assertEqual(translate('Approve'), 'Approve')
-        finally:
-            manager.pop()
-
     def test_add_translation_dirs_abspath(self):
         from pyramid.interfaces import ITranslationDirectories
         config = self._makeOne(autocommit=True)
@@ -103,12 +87,3 @@ class TestI18NConfiguratorMixin(unittest.TestCase):
         self.assertEqual(config.registry.getUtility(ITranslationDirectories),
                          [locale])
 
-class DummyRequest:
-    subpath = ()
-    matchdict = None
-    def __init__(self, environ=None):
-        if environ is None:
-            environ = {}
-        self.environ = environ
-        self.params = {}
-        self.cookies = {}
