@@ -72,10 +72,10 @@ class IntegrationBase(object):
 
 here = os.path.dirname(__file__)
 
-class TestStaticAppBase(IntegrationBase):
+class StaticAppBase(IntegrationBase):
     def test_basic(self):
-        res = self.testapp.get('/minimal.pt', status=200)
-        _assertBody(res.body, os.path.join(here, 'fixtures/minimal.pt'))
+        res = self.testapp.get('/minimal.txt', status=200)
+        _assertBody(res.body, os.path.join(here, 'fixtures/minimal.txt'))
 
     def test_hidden(self):
         res = self.testapp.get('/static/.hiddenfile', status=200)
@@ -119,7 +119,7 @@ class TestStaticAppBase(IntegrationBase):
     def test_not_modified(self):
         self.testapp.extra_environ = {
             'HTTP_IF_MODIFIED_SINCE':httpdate(fiveyrsfuture)}
-        res = self.testapp.get('/minimal.pt', status=304)
+        res = self.testapp.get('/minimal.txt', status=304)
         self.assertEqual(res.body, b'')
 
     def test_file_in_subdir(self):
@@ -198,10 +198,10 @@ class TestEventOnlySubscribers(IntegrationBase, unittest.TestCase):
         self.assertEqual(sorted(res.body.split()),
                          [b'foobar', b'foobar2', b'foobaryup', b'foobaryup2'])
 
-class TestStaticAppUsingAbsPath(TestStaticAppBase, unittest.TestCase):
+class TestStaticAppUsingAbsPath(StaticAppBase, unittest.TestCase):
     package = 'pyramid.tests.pkgs.static_abspath'
 
-class TestStaticAppUsingAssetSpec(TestStaticAppBase, unittest.TestCase):
+class TestStaticAppUsingAssetSpec(StaticAppBase, unittest.TestCase):
     package = 'pyramid.tests.pkgs.static_assetspec'
 
 class TestStaticAppNoSubpath(unittest.TestCase):
@@ -222,19 +222,19 @@ class TestStaticAppNoSubpath(unittest.TestCase):
         return request
 
     def test_basic(self):
-        request = self._makeRequest({'PATH_INFO':'/minimal.pt'})
+        request = self._makeRequest({'PATH_INFO':'/minimal.txt'})
         context = DummyContext()
         result = self.staticapp(context, request)
         self.assertEqual(result.status, '200 OK')
-        _assertBody(result.body, os.path.join(here, 'fixtures/minimal.pt'))
+        _assertBody(result.body, os.path.join(here, 'fixtures/minimal.txt'))
 
 class TestStaticAppWithRoutePrefix(IntegrationBase, unittest.TestCase):
     package = 'pyramid.tests.pkgs.static_routeprefix'
 
     def test_includelevel1(self):
-        res = self.testapp.get('/static/minimal.pt', status=200)
+        res = self.testapp.get('/static/minimal.txt', status=200)
         _assertBody(res.body,
-                    os.path.join(here, 'fixtures/minimal.pt'))
+                    os.path.join(here, 'fixtures/minimal.txt'))
 
     def test_includelevel2(self):
         res = self.testapp.get('/prefix/static/index.html', status=200)
@@ -640,6 +640,78 @@ class RendererScanAppTest(IntegrationBase, unittest.TestCase):
         res = testapp.get('/two', status=200)
         self.assertTrue(b'Two!' in res.body)
 
+class UnicodeInURLTest(unittest.TestCase):
+    def _makeConfig(self):
+        from pyramid.config import Configurator
+        config = Configurator()
+        return config
+
+    def _makeTestApp(self, config):
+        from webtest import TestApp
+        app = config.make_wsgi_app()
+        return TestApp(app)
+
+    def test_unicode_in_url_404(self):
+        request_path = '/avalia%C3%A7%C3%A3o_participante'
+        request_path_unicode = b'/avalia\xc3\xa7\xc3\xa3o_participante'.decode('utf-8')
+
+        config = self._makeConfig()
+        testapp = self._makeTestApp(config)
+
+        res = testapp.get(request_path, status=404)
+
+        # Pyramid default 404 handler outputs:
+        # u'404 Not Found\n\nThe resource could not be found.\n\n\n'
+        # u'/avalia\xe7\xe3o_participante\n\n'
+        self.assertTrue(request_path_unicode in res.text)
+
+    def test_unicode_in_url_200(self):
+        request_path = '/avalia%C3%A7%C3%A3o_participante'
+        request_path_unicode = b'/avalia\xc3\xa7\xc3\xa3o_participante'.decode('utf-8')
+
+        def myview(request):
+            return 'XXX'
+
+        config = self._makeConfig()
+        config.add_route('myroute', request_path_unicode)
+        config.add_view(myview, route_name='myroute', renderer='json')
+        testapp = self._makeTestApp(config)
+
+        res = testapp.get(request_path, status=200)
+
+        self.assertEqual(res.text, '"XXX"')
+
+
+class AcceptContentTypeTest(unittest.TestCase):
+    def setUp(self):
+        def hello_view(request):
+            return {'message': 'Hello!'}
+        from pyramid.config import Configurator
+        config = Configurator()
+        config.add_route('hello', '/hello')
+        config.add_view(hello_view, route_name='hello', accept='text/plain', renderer='string')
+        config.add_view(hello_view, route_name='hello', accept='application/json', renderer='json')
+        app = config.make_wsgi_app()
+        from webtest import TestApp
+        self.testapp = TestApp(app)
+
+    def tearDown(self):
+        import pyramid.config
+        pyramid.config.global_registries.empty()        
+
+    def test_ordering(self):
+        res = self.testapp.get('/hello', headers={'Accept': 'application/json; q=1.0, text/plain; q=0.9'}, status=200)
+        self.assertEqual(res.content_type, 'application/json')
+        res = self.testapp.get('/hello', headers={'Accept': 'text/plain; q=0.9, application/json; q=1.0'}, status=200)
+        self.assertEqual(res.content_type, 'application/json')
+
+    def test_wildcards(self):
+        res = self.testapp.get('/hello', headers={'Accept': 'application/*'}, status=200)
+        self.assertEqual(res.content_type, 'application/json')
+        res = self.testapp.get('/hello', headers={'Accept': 'text/*'}, status=200)
+        self.assertEqual(res.content_type, 'text/plain')
+
+
 class DummyContext(object):
     pass
 
