@@ -1,6 +1,17 @@
 import unittest
 from pyramid import testing
 
+from pyramid.compat import (
+    PY3,
+    text_,
+    bytes_,
+    native_,
+    )
+from pyramid.security import (
+    AuthenticationAPIMixin,
+    AuthorizationAPIMixin,
+    )
+
 class TestRequest(unittest.TestCase):
     def setUp(self):
         self.config = testing.setUp()
@@ -8,24 +19,45 @@ class TestRequest(unittest.TestCase):
     def tearDown(self):
         testing.tearDown()
 
-    def _makeOne(self, environ):
-        return self._getTargetClass()(environ)
-
     def _getTargetClass(self):
         from pyramid.request import Request
         return Request
 
-    def _registerContextURL(self):
-        from pyramid.interfaces import IContextURL
+    def _makeOne(self, environ=None):
+        if environ is None:
+            environ = {}
+        return self._getTargetClass()(environ)
+
+    def _registerResourceURL(self):
+        from pyramid.interfaces import IResourceURL
         from zope.interface import Interface
-        class DummyContextURL(object):
+        class DummyResourceURL(object):
             def __init__(self, context, request):
-                pass
-            def __call__(self):
-                return 'http://example.com/context/'
+                self.physical_path = '/context/'
+                self.virtual_path = '/context/'
         self.config.registry.registerAdapter(
-            DummyContextURL, (Interface, Interface),
-            IContextURL)
+            DummyResourceURL, (Interface, Interface),
+            IResourceURL)
+
+    def test_class_conforms_to_IRequest(self):
+        from zope.interface.verify import verifyClass
+        from pyramid.interfaces import IRequest
+        verifyClass(IRequest, self._getTargetClass())
+
+    def test_instance_conforms_to_IRequest(self):
+        from zope.interface.verify import verifyObject
+        from pyramid.interfaces import IRequest
+        verifyObject(IRequest, self._makeOne())
+
+    def test_ResponseClass_is_pyramid_Response(self):
+        from pyramid.response import Response
+        cls = self._getTargetClass()
+        self.assertEqual(cls.ResponseClass, Response)
+
+    def test_implements_security_apis(self):
+        apis = (AuthenticationAPIMixin, AuthorizationAPIMixin)
+        r = self._makeOne()
+        self.assertTrue(isinstance(r, apis))
 
     def test_charset_defaults_to_utf8(self):
         r = self._makeOne({'PATH_INFO':'/'})
@@ -50,27 +82,17 @@ class TestRequest(unittest.TestCase):
             }
         request = self._makeOne(environ)
         request.charset = None
-        self.assertEqual(request.GET['la'], u'La Pe\xf1a')
-
-    def test_class_implements(self):
-        from pyramid.interfaces import IRequest
-        klass = self._getTargetClass()
-        self.assertTrue(IRequest.implementedBy(klass))
-
-    def test_instance_provides(self):
-        from pyramid.interfaces import IRequest
-        inst = self._makeOne({})
-        self.assertTrue(IRequest.providedBy(inst))
+        self.assertEqual(request.GET['la'], text_(b'La Pe\xf1a'))
 
     def test_tmpl_context(self):
         from pyramid.request import TemplateContext
-        inst = self._makeOne({})
+        inst = self._makeOne()
         result = inst.tmpl_context
         self.assertEqual(result.__class__, TemplateContext)
 
     def test_session_configured(self):
         from pyramid.interfaces import ISessionFactory
-        inst = self._makeOne({})
+        inst = self._makeOne()
         def factory(request):
             return 'orangejuice'
         self.config.registry.registerUtility(factory, ISessionFactory)
@@ -79,13 +101,12 @@ class TestRequest(unittest.TestCase):
         self.assertEqual(inst.__dict__['session'], 'orangejuice')
 
     def test_session_not_configured(self):
-        from pyramid.exceptions import ConfigurationError
-        inst = self._makeOne({})
+        inst = self._makeOne()
         inst.registry = self.config.registry
-        self.assertRaises(ConfigurationError, getattr, inst, 'session')
+        self.assertRaises(AttributeError, getattr, inst, 'session')
 
     def test_setattr_and_getattr_dotnotation(self):
-        inst = self._makeOne({})
+        inst = self._makeOne()
         inst.foo = 1
         self.assertEqual(inst.foo, 1)
 
@@ -97,7 +118,7 @@ class TestRequest(unittest.TestCase):
         self.assertEqual(environ, {}) # make sure we're not using adhoc attrs
 
     def test_add_response_callback(self):
-        inst = self._makeOne({})
+        inst = self._makeOne()
         self.assertEqual(inst.response_callbacks, ())
         def callback(request, response):
             """ """
@@ -107,7 +128,7 @@ class TestRequest(unittest.TestCase):
         self.assertEqual(inst.response_callbacks, [callback, callback])
 
     def test__process_response_callbacks(self):
-        inst = self._makeOne({})
+        inst = self._makeOne()
         def callback1(request, response):
             request.called1 = True
             response.called1 = True
@@ -124,7 +145,7 @@ class TestRequest(unittest.TestCase):
         self.assertEqual(inst.response_callbacks, [])
 
     def test_add_finished_callback(self):
-        inst = self._makeOne({})
+        inst = self._makeOne()
         self.assertEqual(inst.finished_callbacks, ())
         def callback(request):
             """ """
@@ -134,7 +155,7 @@ class TestRequest(unittest.TestCase):
         self.assertEqual(inst.finished_callbacks, [callback, callback])
 
     def test__process_finished_callbacks(self):
-        inst = self._makeOne({})
+        inst = self._makeOne()
         def callback1(request):
             request.called1 = True
         def callback2(request):
@@ -146,8 +167,14 @@ class TestRequest(unittest.TestCase):
         self.assertEqual(inst.finished_callbacks, [])
 
     def test_resource_url(self):
-        self._registerContextURL()
-        inst = self._makeOne({})
+        self._registerResourceURL()
+        environ = {
+            'PATH_INFO':'/',
+            'SERVER_NAME':'example.com',
+            'SERVER_PORT':'80',
+            'wsgi.url_scheme':'http',
+            }
+        inst = self._makeOne(environ)
         root = DummyContext()
         result = inst.resource_url(root)
         self.assertEqual(result, 'http://example.com/context/')
@@ -166,7 +193,7 @@ class TestRequest(unittest.TestCase):
         self.config.registry.registerUtility(mapper, IRoutesMapper)
         result = inst.route_url('flub', 'extra1', 'extra2',
                                 a=1, b=2, c=3, _query={'a':1},
-                                _anchor=u"foo")
+                                _anchor=text_("foo"))
         self.assertEqual(result,
                          'http://example.com:5432/1/2/3/extra1/extra2?a=1#foo')
 
@@ -184,7 +211,7 @@ class TestRequest(unittest.TestCase):
         self.config.registry.registerUtility(mapper, IRoutesMapper)
         result = inst.route_path('flub', 'extra1', 'extra2',
                                 a=1, b=2, c=3, _query={'a':1},
-                                _anchor=u"foo")
+                                _anchor=text_("foo"))
         self.assertEqual(result, '/1/2/3/extra1/extra2?a=1#foo')
 
     def test_static_url(self):
@@ -205,13 +232,20 @@ class TestRequest(unittest.TestCase):
                          ('pyramid.tests:static/foo.css', request, {}) )
 
     def test_is_response_false(self):
-        request = self._makeOne({})
+        request = self._makeOne()
         request.registry = self.config.registry
         self.assertEqual(request.is_response('abc'), False)
 
+    def test_is_response_true_ob_is_pyramid_response(self):
+        from pyramid.response import Response
+        r = Response('hello')
+        request = self._makeOne()
+        request.registry = self.config.registry
+        self.assertEqual(request.is_response(r), True)
+
     def test_is_response_false_adapter_is_not_self(self):
         from pyramid.interfaces import IResponse
-        request = self._makeOne({})
+        request = self._makeOne()
         request.registry = self.config.registry
         def adapter(ob):
             return object()
@@ -223,7 +257,7 @@ class TestRequest(unittest.TestCase):
         
     def test_is_response_adapter_true(self):
         from pyramid.interfaces import IResponse
-        request = self._makeOne({})
+        request = self._makeOne()
         request.registry = self.config.registry
         class Foo(object):
             pass
@@ -235,19 +269,25 @@ class TestRequest(unittest.TestCase):
 
     def test_json_body_invalid_json(self):
         request = self._makeOne({'REQUEST_METHOD':'POST'})
-        request.body = '{'
+        request.body = b'{'
         self.assertRaises(ValueError, getattr, request, 'json_body')
         
     def test_json_body_valid_json(self):
         request = self._makeOne({'REQUEST_METHOD':'POST'})
-        request.body = '{"a":1}'
+        request.body = b'{"a":1}'
         self.assertEqual(request.json_body, {'a':1})
 
     def test_json_body_alternate_charset(self):
-        from pyramid.compat import json
+        import json
         request = self._makeOne({'REQUEST_METHOD':'POST'})
-        inp ='/\xe6\xb5\x81\xe8\xa1\x8c\xe8\xb6\x8b\xe5\x8a\xbf'.decode('utf-8')
-        body = json.dumps({'a':inp}).decode('utf-8').encode('utf-16')
+        inp = text_(
+            b'/\xe6\xb5\x81\xe8\xa1\x8c\xe8\xb6\x8b\xe5\x8a\xbf',
+            'utf-8'
+            )
+        if PY3: # pragma: no cover
+            body = bytes(json.dumps({'a':inp}), 'utf-16')
+        else:
+            body = json.dumps({'a':inp}).decode('utf-8').encode('utf-16')
         request.body = body
         request.content_type = 'application/json; charset=utf-16'
         self.assertEqual(request.json_body, {'a':inp})
@@ -256,162 +296,23 @@ class TestRequest(unittest.TestCase):
         request = self._makeOne({'REQUEST_METHOD':'GET'})
         self.assertRaises(ValueError, getattr, request, 'json_body')
 
-class TestRequestDeprecatedMethods(unittest.TestCase):
-    def setUp(self):
-        self.config = testing.setUp()
-        from zope.deprecation import __show__
-        __show__.off()
+    def test_set_property(self):
+        request = self._makeOne()
+        opts = [2, 1]
+        def connect(obj):
+            return opts.pop()
+        request.set_property(connect, name='db')
+        self.assertEqual(1, request.db)
+        self.assertEqual(2, request.db)
 
-    def tearDown(self):
-        testing.tearDown()
-        from zope.deprecation import __show__
-        __show__.on()
-
-    def _getTargetClass(self):
-        from pyramid.request import Request
-        return Request
-
-    def _makeOne(self, environ=None):
-        if environ is None:
-            environ = {}
-        return self._getTargetClass()(environ)
-
-    def test___contains__(self):
-        environ ={'zooma':1}
-        inst = self._makeOne(environ)
-        self.assertTrue('zooma' in inst)
-
-    def test___delitem__(self):
-        environ = {'zooma':1}
-        inst = self._makeOne(environ)
-        del inst['zooma']
-        self.assertFalse('zooma' in environ)
-
-    def test___getitem__(self):
-        environ = {'zooma':1}
-        inst = self._makeOne(environ)
-        self.assertEqual(inst['zooma'], 1)
-
-    def test___iter__(self):
-        environ = {'zooma':1}
-        inst = self._makeOne(environ)
-        iterator = iter(inst)
-        self.assertEqual(list(iterator), list(iter(environ)))
-
-    def test___setitem__(self):
-        environ = {}
-        inst = self._makeOne(environ)
-        inst['zooma'] = 1
-        self.assertEqual(environ, {'zooma':1})
-
-    def test_get(self):
-        environ = {'zooma':1}
-        inst = self._makeOne(environ)
-        self.assertEqual(inst.get('zooma'), 1)
-
-    def test_has_key(self):
-        environ = {'zooma':1}
-        inst = self._makeOne(environ)
-        self.assertEqual(inst.has_key('zooma'), True)
-
-    def test_items(self):
-        environ = {'zooma':1}
-        inst = self._makeOne(environ)
-        self.assertEqual(inst.items(), environ.items())
-
-    def test_iteritems(self):
-        environ = {'zooma':1}
-        inst = self._makeOne(environ)
-        self.assertEqual(list(inst.iteritems()), list(environ.iteritems()))
-
-    def test_iterkeys(self):
-        environ = {'zooma':1}
-        inst = self._makeOne(environ)
-        self.assertEqual(list(inst.iterkeys()), list(environ.iterkeys()))
-
-    def test_itervalues(self):
-        environ = {'zooma':1}
-        inst = self._makeOne(environ)
-        self.assertEqual(list(inst.itervalues()), list(environ.itervalues()))
-
-    def test_keys(self):
-        environ = {'zooma':1}
-        inst = self._makeOne(environ)
-        self.assertEqual(inst.keys(), environ.keys())
-
-    def test_pop(self):
-        environ = {'zooma':1}
-        inst = self._makeOne(environ)
-        popped = inst.pop('zooma')
-        self.assertEqual(environ, {})
-        self.assertEqual(popped, 1)
-
-    def test_popitem(self):
-        environ = {'zooma':1}
-        inst = self._makeOne(environ)
-        popped = inst.popitem()
-        self.assertEqual(environ, {})
-        self.assertEqual(popped, ('zooma', 1))
-
-    def test_setdefault(self):
-        environ = {}
-        inst = self._makeOne(environ)
-        marker = []
-        result = inst.setdefault('a', marker)
-        self.assertEqual(environ, {'a':marker})
-        self.assertEqual(result, marker)
-
-    def test_update(self):
-        environ = {}
-        inst = self._makeOne(environ)
-        inst.update({'a':1}, b=2)
-        self.assertEqual(environ, {'a':1, 'b':2})
-
-    def test_values(self):
-        environ = {'zooma':1}
-        inst = self._makeOne(environ)
-        result = inst.values()
-        self.assertEqual(result, environ.values())
-
-    def test_response_content_type(self):
-        inst = self._makeOne()
-        self.assertFalse(hasattr(inst, 'response_content_type'))
-        inst.response_content_type = 'abc'
-        self.assertEqual(inst.response_content_type, 'abc')
-        del inst.response_content_type
-        self.assertFalse(hasattr(inst, 'response_content_type'))
-
-    def test_response_headerlist(self):
-        inst = self._makeOne()
-        self.assertFalse(hasattr(inst, 'response_headerlist'))
-        inst.response_headerlist = 'abc'
-        self.assertEqual(inst.response_headerlist, 'abc')
-        del inst.response_headerlist
-        self.assertFalse(hasattr(inst, 'response_headerlist'))
-
-    def test_response_status(self):
-        inst = self._makeOne()
-        self.assertFalse(hasattr(inst, 'response_status'))
-        inst.response_status = 'abc'
-        self.assertEqual(inst.response_status, 'abc')
-        del inst.response_status
-        self.assertFalse(hasattr(inst, 'response_status'))
-
-    def test_response_charset(self):
-        inst = self._makeOne()
-        self.assertFalse(hasattr(inst, 'response_charset'))
-        inst.response_charset = 'abc'
-        self.assertEqual(inst.response_charset, 'abc')
-        del inst.response_charset
-        self.assertFalse(hasattr(inst, 'response_charset'))
-
-    def test_response_cache_for(self):
-        inst = self._makeOne()
-        self.assertFalse(hasattr(inst, 'response_cache_for'))
-        inst.response_cache_for = 'abc'
-        self.assertEqual(inst.response_cache_for, 'abc')
-        del inst.response_cache_for
-        self.assertFalse(hasattr(inst, 'response_cache_for'))
+    def test_set_property_reify(self):
+        request = self._makeOne()
+        opts = [2, 1]
+        def connect(obj):
+            return opts.pop()
+        request.set_property(connect, name='db', reify=True)
+        self.assertEqual(1, request.db)
+        self.assertEqual(1, request.db)
 
 class Test_route_request_iface(unittest.TestCase):
     def _callFUT(self, name):
@@ -497,14 +398,16 @@ class Test_call_app_with_subpath_as_path_info(unittest.TestCase):
         self.assertEqual(request.environ['PATH_INFO'], '/hello/')
 
     def test_subpath_path_info_and_script_name_have_utf8(self):
-        la = 'La Pe\xc3\xb1a'
-        request = DummyRequest({'PATH_INFO':'/'+la, 'SCRIPT_NAME':'/'+la})
-        request.subpath = (unicode(la, 'utf-8'), )
+        encoded = native_(text_(b'La Pe\xc3\xb1a'))
+        decoded = text_(bytes_(encoded), 'utf-8')
+        request = DummyRequest({'PATH_INFO':'/' + encoded,
+                                'SCRIPT_NAME':'/' + encoded})
+        request.subpath = (decoded, )
         response = self._callFUT(request, 'app')
         self.assertTrue(request.copied)
         self.assertEqual(response, 'app')
-        self.assertEqual(request.environ['SCRIPT_NAME'], '/' + la)
-        self.assertEqual(request.environ['PATH_INFO'], '/' + la)
+        self.assertEqual(request.environ['SCRIPT_NAME'], '/' + encoded)
+        self.assertEqual(request.environ['PATH_INFO'], '/' + encoded)
 
 class DummyRequest:
     def __init__(self, environ=None):
