@@ -1,5 +1,9 @@
+import datetime
 import unittest
 
+# 5 years from now (more or less)
+fiveyrsfuture = datetime.datetime.utcnow() + datetime.timedelta(5*365)
+
 class Test_static_view_use_subpath_False(unittest.TestCase):
     def _getTargetClass(self):
         from pyramid.static import static_view
@@ -34,17 +38,15 @@ class Test_static_view_use_subpath_False(unittest.TestCase):
         inst = self._makeOne('pyramid.tests:fixtures/static')
         request = self._makeRequest({'PATH_INFO':''})
         context = DummyContext()
-        response = inst(context, request)
-        response.prepare(request.environ)
-        self.assertEqual(response.status, '301 Moved Permanently')
-        self.assertTrue('http://example.com:6543/' in response.body)
-        
+        from pyramid.httpexceptions import HTTPMovedPermanently
+        self.assertRaises(HTTPMovedPermanently, inst, context, request)
+
     def test_path_info_slash_means_index_html(self):
         inst = self._makeOne('pyramid.tests:fixtures/static')
         request = self._makeRequest()
         context = DummyContext()
         response = inst(context, request)
-        self.assertTrue('<html>static</html>' in response.body)
+        self.assertTrue(b'<html>static</html>' in response.body)
 
     def test_oob_singledot(self):
         inst = self._makeOne('pyramid.tests:fixtures/static')
@@ -52,7 +54,7 @@ class Test_static_view_use_subpath_False(unittest.TestCase):
         context = DummyContext()
         response = inst(context, request)
         self.assertEqual(response.status, '200 OK')
-        self.assertTrue('<html>static</html>' in response.body)
+        self.assertTrue(b'<html>static</html>' in response.body)
 
     def test_oob_emptyelement(self):
         inst = self._makeOne('pyramid.tests:fixtures/static')
@@ -60,22 +62,22 @@ class Test_static_view_use_subpath_False(unittest.TestCase):
         context = DummyContext()
         response = inst(context, request)
         self.assertEqual(response.status, '200 OK')
-        self.assertTrue('<html>static</html>' in response.body)
+        self.assertTrue(b'<html>static</html>' in response.body)
 
     def test_oob_dotdotslash(self):
         inst = self._makeOne('pyramid.tests:fixtures/static')
         request = self._makeRequest({'PATH_INFO':'/subdir/../../minimal.pt'})
         context = DummyContext()
-        response = inst(context, request)
-        self.assertEqual(response.status, '404 Not Found')
+        from pyramid.httpexceptions import HTTPNotFound
+        self.assertRaises(HTTPNotFound, inst, context, request)
 
     def test_oob_dotdotslash_encoded(self):
         inst = self._makeOne('pyramid.tests:fixtures/static')
         request = self._makeRequest(
             {'PATH_INFO':'/subdir/%2E%2E%2F%2E%2E/minimal.pt'})
         context = DummyContext()
-        response = inst(context, request)
-        self.assertEqual(response.status, '404 Not Found')
+        from pyramid.httpexceptions import HTTPNotFound
+        self.assertRaises(HTTPNotFound, inst, context, request)
 
     def test_oob_os_sep(self):
         import os
@@ -84,36 +86,53 @@ class Test_static_view_use_subpath_False(unittest.TestCase):
         request = self._makeRequest({'PATH_INFO':'/subdir/%s%sminimal.pt' %
                                      (dds, dds)})
         context = DummyContext()
-        response = inst(context, request)
-        self.assertEqual(response.status, '404 Not Found')
+        from pyramid.httpexceptions import HTTPNotFound
+        self.assertRaises(HTTPNotFound, inst, context, request)
 
     def test_resource_doesnt_exist(self):
         inst = self._makeOne('pyramid.tests:fixtures/static')
         request = self._makeRequest({'PATH_INFO':'/notthere'})
         context = DummyContext()
-        response = inst(context, request)
-        self.assertEqual(response.status, '404 Not Found')
+        from pyramid.httpexceptions import HTTPNotFound
+        self.assertRaises(HTTPNotFound, inst, context, request)
 
     def test_resource_isdir(self):
         inst = self._makeOne('pyramid.tests:fixtures/static')
         request = self._makeRequest({'PATH_INFO':'/subdir/'})
         context = DummyContext()
         response = inst(context, request)
-        self.assertTrue('<html>subdir</html>' in response.body)
+        self.assertTrue(b'<html>subdir</html>' in response.body)
 
     def test_resource_is_file(self):
         inst = self._makeOne('pyramid.tests:fixtures/static')
         request = self._makeRequest({'PATH_INFO':'/index.html'})
         context = DummyContext()
         response = inst(context, request)
-        self.assertTrue('<html>static</html>' in response.body)
+        self.assertTrue(b'<html>static</html>' in response.body)
+
+    def test_resource_is_file_with_wsgi_file_wrapper(self):
+        from pyramid.response import _BLOCK_SIZE
+        inst = self._makeOne('pyramid.tests:fixtures/static')
+        request = self._makeRequest({'PATH_INFO':'/index.html'})
+        class _Wrapper(object):
+            def __init__(self, file, block_size=None):
+                self.file = file
+                self.block_size = block_size
+        request.environ['wsgi.file_wrapper'] = _Wrapper
+        context = DummyContext()
+        response = inst(context, request)
+        app_iter = response.app_iter
+        self.assertTrue(isinstance(app_iter, _Wrapper))
+        self.assertTrue(b'<html>static</html>' in app_iter.file.read())
+        self.assertEqual(app_iter.block_size, _BLOCK_SIZE)
+        app_iter.file.close()
 
     def test_resource_is_file_with_cache_max_age(self):
         inst = self._makeOne('pyramid.tests:fixtures/static', cache_max_age=600)
         request = self._makeRequest({'PATH_INFO':'/index.html'})
         context = DummyContext()
         response = inst(context, request)
-        self.assertTrue('<html>static</html>' in response.body)
+        self.assertTrue(b'<html>static</html>' in response.body)
         self.assertEqual(len(response.headerlist), 5)
         header_names = [ x[0] for x in response.headerlist ]
         header_names.sort()
@@ -127,7 +146,7 @@ class Test_static_view_use_subpath_False(unittest.TestCase):
         request = self._makeRequest({'PATH_INFO':'/index.html'})
         context = DummyContext()
         response = inst(context, request)
-        self.assertTrue('<html>static</html>' in response.body)
+        self.assertTrue(b'<html>static</html>' in response.body)
         self.assertEqual(len(response.headerlist), 3)
         header_names = [ x[0] for x in response.headerlist ]
         header_names.sort()
@@ -138,20 +157,43 @@ class Test_static_view_use_subpath_False(unittest.TestCase):
     def test_resource_notmodified(self):
         inst = self._makeOne('pyramid.tests:fixtures/static')
         request = self._makeRequest({'PATH_INFO':'/index.html'})
-        request.if_modified_since = pow(2, 32) -1
+        request.if_modified_since = fiveyrsfuture
         context = DummyContext()
         response = inst(context, request)
         start_response = DummyStartResponse()
         app_iter = response(request.environ, start_response)
-        self.assertEqual(start_response.status, '304 Not Modified')
-        self.assertEqual(list(app_iter), [])
+        try:
+            self.assertEqual(start_response.status, '304 Not Modified')
+            self.assertEqual(list(app_iter), [])
+        finally:
+            app_iter.close()
 
     def test_not_found(self):
         inst = self._makeOne('pyramid.tests:fixtures/static')
         request = self._makeRequest({'PATH_INFO':'/notthere.html'})
         context = DummyContext()
+        from pyramid.httpexceptions import HTTPNotFound
+        self.assertRaises(HTTPNotFound, inst, context, request)
+
+    def test_resource_with_content_encoding(self):
+        inst = self._makeOne('pyramid.tests:fixtures/static')
+        request = self._makeRequest({'PATH_INFO':'/arcs.svg.tgz'})
+        context = DummyContext()
         response = inst(context, request)
-        self.assertEqual(response.status, '404 Not Found')
+        self.assertEqual(response.status, '200 OK')
+        self.assertEqual(response.content_type, 'application/x-tar')
+        self.assertEqual(response.content_encoding, 'gzip')
+        response.app_iter.close()
+
+    def test_resource_no_content_encoding(self):
+        inst = self._makeOne('pyramid.tests:fixtures/static')
+        request = self._makeRequest({'PATH_INFO':'/index.html'})
+        context = DummyContext()
+        response = inst(context, request)
+        self.assertEqual(response.status, '200 OK')
+        self.assertEqual(response.content_type, 'text/html')
+        self.assertEqual(response.content_encoding, None)
+        response.app_iter.close()
 
 class Test_static_view_use_subpath_True(unittest.TestCase):
     def _getTargetClass(self):
@@ -189,51 +231,49 @@ class Test_static_view_use_subpath_True(unittest.TestCase):
         request = self._makeRequest({'PATH_INFO':''})
         request.subpath = ()
         context = DummyContext()
-        response = inst(context, request)
-        response.prepare(request.environ)
-        self.assertEqual(response.status, '301 Moved Permanently')
-        self.assertTrue('http://example.com:6543/' in response.body)
-        
+        from pyramid.httpexceptions import HTTPMovedPermanently
+        self.assertRaises(HTTPMovedPermanently, inst, context, request)
+
     def test_path_info_slash_means_index_html(self):
         inst = self._makeOne('pyramid.tests:fixtures/static')
         request = self._makeRequest()
         request.subpath = ()
         context = DummyContext()
         response = inst(context, request)
-        self.assertTrue('<html>static</html>' in response.body)
+        self.assertTrue(b'<html>static</html>' in response.body)
 
     def test_oob_singledot(self):
         inst = self._makeOne('pyramid.tests:fixtures/static')
         request = self._makeRequest()
         request.subpath = ('.', 'index.html')
         context = DummyContext()
-        response = inst(context, request)
-        self.assertEqual(response.status, '404 Not Found')
+        from pyramid.httpexceptions import HTTPNotFound
+        self.assertRaises(HTTPNotFound, inst, context, request)
 
     def test_oob_emptyelement(self):
         inst = self._makeOne('pyramid.tests:fixtures/static')
         request = self._makeRequest()
         request.subpath = ('', 'index.html')
         context = DummyContext()
-        response = inst(context, request)
-        self.assertEqual(response.status, '404 Not Found')
+        from pyramid.httpexceptions import HTTPNotFound
+        self.assertRaises(HTTPNotFound, inst, context, request)
 
     def test_oob_dotdotslash(self):
         inst = self._makeOne('pyramid.tests:fixtures/static')
         request = self._makeRequest()
         request.subpath = ('subdir', '..', '..', 'minimal.pt')
         context = DummyContext()
-        response = inst(context, request)
-        self.assertEqual(response.status, '404 Not Found')
+        from pyramid.httpexceptions import HTTPNotFound
+        self.assertRaises(HTTPNotFound, inst, context, request)
 
     def test_oob_dotdotslash_encoded(self):
         inst = self._makeOne('pyramid.tests:fixtures/static')
         request = self._makeRequest()
         request.subpath = ('subdir', '%2E%2E', '%2E%2E', 'minimal.pt')
         context = DummyContext()
-        response = inst(context, request)
-        self.assertEqual(response.status, '404 Not Found')
-
+        from pyramid.httpexceptions import HTTPNotFound
+        self.assertRaises(HTTPNotFound, inst, context, request)
+        
     def test_oob_os_sep(self):
         import os
         inst = self._makeOne('pyramid.tests:fixtures/static')
@@ -241,16 +281,16 @@ class Test_static_view_use_subpath_True(unittest.TestCase):
         request = self._makeRequest()
         request.subpath = ('subdir', dds, dds, 'minimal.pt')
         context = DummyContext()
-        response = inst(context, request)
-        self.assertEqual(response.status, '404 Not Found')
+        from pyramid.httpexceptions import HTTPNotFound
+        self.assertRaises(HTTPNotFound, inst, context, request)
 
     def test_resource_doesnt_exist(self):
         inst = self._makeOne('pyramid.tests:fixtures/static')
         request = self._makeRequest()
         request.subpath = ('notthere,')
         context = DummyContext()
-        response = inst(context, request)
-        self.assertEqual(response.status, '404 Not Found')
+        from pyramid.httpexceptions import HTTPNotFound
+        self.assertRaises(HTTPNotFound, inst, context, request)
 
     def test_resource_isdir(self):
         inst = self._makeOne('pyramid.tests:fixtures/static')
@@ -258,7 +298,7 @@ class Test_static_view_use_subpath_True(unittest.TestCase):
         request.subpath = ('subdir',)
         context = DummyContext()
         response = inst(context, request)
-        self.assertTrue('<html>subdir</html>' in response.body)
+        self.assertTrue(b'<html>subdir</html>' in response.body)
 
     def test_resource_is_file(self):
         inst = self._makeOne('pyramid.tests:fixtures/static')
@@ -266,7 +306,7 @@ class Test_static_view_use_subpath_True(unittest.TestCase):
         request.subpath = ('index.html',)
         context = DummyContext()
         response = inst(context, request)
-        self.assertTrue('<html>static</html>' in response.body)
+        self.assertTrue(b'<html>static</html>' in response.body)
 
     def test_resource_is_file_with_cache_max_age(self):
         inst = self._makeOne('pyramid.tests:fixtures/static', cache_max_age=600)
@@ -274,7 +314,7 @@ class Test_static_view_use_subpath_True(unittest.TestCase):
         request.subpath = ('index.html',)
         context = DummyContext()
         response = inst(context, request)
-        self.assertTrue('<html>static</html>' in response.body)
+        self.assertTrue(b'<html>static</html>' in response.body)
         self.assertEqual(len(response.headerlist), 5)
         header_names = [ x[0] for x in response.headerlist ]
         header_names.sort()
@@ -289,7 +329,7 @@ class Test_static_view_use_subpath_True(unittest.TestCase):
         request.subpath = ('index.html',)
         context = DummyContext()
         response = inst(context, request)
-        self.assertTrue('<html>static</html>' in response.body)
+        self.assertTrue(b'<html>static</html>' in response.body)
         self.assertEqual(len(response.headerlist), 3)
         header_names = [ x[0] for x in response.headerlist ]
         header_names.sort()
@@ -300,43 +340,25 @@ class Test_static_view_use_subpath_True(unittest.TestCase):
     def test_resource_notmodified(self):
         inst = self._makeOne('pyramid.tests:fixtures/static')
         request = self._makeRequest()
-        request.if_modified_since = pow(2, 32) -1
+        request.if_modified_since = fiveyrsfuture
         request.subpath = ('index.html',)
         context = DummyContext()
         response = inst(context, request)
         start_response = DummyStartResponse()
         app_iter = response(request.environ, start_response)
-        self.assertEqual(start_response.status, '304 Not Modified')
-        self.assertEqual(list(app_iter), [])
+        try:
+            self.assertEqual(start_response.status, '304 Not Modified')
+            self.assertEqual(list(app_iter), [])
+        finally:
+            app_iter.close()
 
     def test_not_found(self):
         inst = self._makeOne('pyramid.tests:fixtures/static')
         request = self._makeRequest()
         request.subpath = ('notthere.html',)
         context = DummyContext()
-        response = inst(context, request)
-        self.assertEqual(response.status, '404 Not Found')
-
-class Test_patch_mimetypes(unittest.TestCase):
-    def _callFUT(self, module):
-        from pyramid.static import init_mimetypes
-        return init_mimetypes(module)
-
-    def test_has_init(self):
-        class DummyMimetypes(object):
-            def init(self):
-                self.initted = True
-        module = DummyMimetypes()
-        result = self._callFUT(module)
-        self.assertEqual(result, True)
-        self.assertEqual(module.initted, True)
-        
-    def test_missing_init(self):
-        class DummyMimetypes(object):
-            pass
-        module = DummyMimetypes()
-        result = self._callFUT(module)
-        self.assertEqual(result, False)
+        from pyramid.httpexceptions import HTTPNotFound
+        self.assertRaises(HTTPNotFound, inst, context, request)
 
 class DummyContext:
     pass
