@@ -117,7 +117,7 @@ class TestDummyResource(unittest.TestCase):
     def test_bool(self):
         resource = self._makeOne()
         self.assertEqual(resource.__bool__(), True)
-
+        
     def test_ctor_with__provides__(self):
         resource = self._makeOne(__provides__=IDummy)
         self.assertTrue(IDummy.providedBy(resource))
@@ -347,6 +347,7 @@ class Test_setUp(unittest.TestCase):
         self.assertEqual(config.registry, current['registry'])
         self.assertEqual(current['registry'].__class__, Registry)
         self.assertEqual(current['request'], None)
+        self.assertEqual(config.package.__name__, 'pyramid.tests')
         self._assertSMHook(get_current_registry)
 
     def test_it_with_registry(self):
@@ -364,6 +365,10 @@ class Test_setUp(unittest.TestCase):
         current = manager.get()
         self.assertEqual(current['request'], request)
 
+    def test_it_with_package(self):
+        config = self._callFUT(package='pyramid')
+        self.assertEqual(config.package.__name__, 'pyramid')
+
     def test_it_with_hook_zca_false(self):
         from pyramid.registry import Registry
         registry = Registry()
