@@ -1,15 +1,16 @@
 import unittest
 import sys
 
-from pyramid.testing import setUp
-from pyramid.testing import tearDown
+from zope.interface import implementer
+
+from pyramid import testing
 
 class BaseTest(object):
     def setUp(self):
-        self.config = setUp()
+        self.config = testing.setUp()
 
     def tearDown(self):
-        tearDown()
+        testing.tearDown()
 
     def _registerView(self, reg, app, name):
         from pyramid.interfaces import IRequest
@@ -46,8 +47,94 @@ class BaseTest(object):
         context = DummyContext()
         directlyProvides(context, IContext)
         return context
-        
 
+class Test_notfound_view_config(BaseTest, unittest.TestCase):
+    def _makeOne(self, **kw):
+        from pyramid.view import notfound_view_config
+        return notfound_view_config(**kw)
+
+    def test_ctor(self):
+        inst = self._makeOne(attr='attr', path_info='path_info', 
+                             append_slash=True)
+        self.assertEqual(inst.__dict__,
+                         {'attr':'attr', 'path_info':'path_info',
+                          'append_slash':True})
+
+    def test_it_function(self):
+        def view(request): pass
+        decorator = self._makeOne(attr='attr', renderer='renderer',
+                                  append_slash=True)
+        venusian = DummyVenusian()
+        decorator.venusian = venusian
+        wrapped = decorator(view)
+        self.assertTrue(wrapped is view)
+        config = call_venusian(venusian)
+        settings = config.settings
+        self.assertEqual(
+            settings, 
+            [{'attr': 'attr', 'venusian': venusian, 'append_slash': True, 
+              'renderer': 'renderer', '_info': 'codeinfo', 'view': None}]
+            )
+
+    def test_it_class(self):
+        decorator = self._makeOne()
+        venusian = DummyVenusian()
+        decorator.venusian = venusian
+        decorator.venusian.info.scope = 'class'
+        class view(object): pass
+        wrapped = decorator(view)
+        self.assertTrue(wrapped is view)
+        config = call_venusian(venusian)
+        settings = config.settings
+        self.assertEqual(len(settings), 1)
+        self.assertEqual(len(settings[0]), 4)
+        self.assertEqual(settings[0]['venusian'], venusian)
+        self.assertEqual(settings[0]['view'], None) # comes from call_venusian
+        self.assertEqual(settings[0]['attr'], 'view')
+        self.assertEqual(settings[0]['_info'], 'codeinfo')
+
+class Test_forbidden_view_config(BaseTest, unittest.TestCase):
+    def _makeOne(self, **kw):
+        from pyramid.view import forbidden_view_config
+        return forbidden_view_config(**kw)
+
+    def test_ctor(self):
+        inst = self._makeOne(attr='attr', path_info='path_info')
+        self.assertEqual(inst.__dict__,
+                         {'attr':'attr', 'path_info':'path_info'})
+
+    def test_it_function(self):
+        def view(request): pass
+        decorator = self._makeOne(attr='attr', renderer='renderer')
+        venusian = DummyVenusian()
+        decorator.venusian = venusian
+        wrapped = decorator(view)
+        self.assertTrue(wrapped is view)
+        config = call_venusian(venusian)
+        settings = config.settings
+        self.assertEqual(
+            settings, 
+            [{'attr': 'attr', 'venusian': venusian, 
+              'renderer': 'renderer', '_info': 'codeinfo', 'view': None}]
+            )
+
+    def test_it_class(self):
+        decorator = self._makeOne()
+        venusian = DummyVenusian()
+        decorator.venusian = venusian
+        decorator.venusian.info.scope = 'class'
+        class view(object): pass
+        wrapped = decorator(view)
+        self.assertTrue(wrapped is view)
+        config = call_venusian(venusian)
+        settings = config.settings
+        self.assertEqual(len(settings), 1)
+        self.assertEqual(len(settings[0]), 4)
+        self.assertEqual(settings[0]['venusian'], venusian)
+        self.assertEqual(settings[0]['view'], None) # comes from call_venusian
+        self.assertEqual(settings[0]['attr'], 'view')
+        self.assertEqual(settings[0]['_info'], 'codeinfo')
+        
 class RenderViewToResponseTests(BaseTest, unittest.TestCase):
     def _callFUT(self, *arg, **kw):
         from pyramid.view import render_view_to_response
@@ -137,12 +224,29 @@ class RenderViewToIterableTests(BaseTest, unittest.TestCase):
         response = DummyResponse()
         view = make_view(response)
         def anotherview(context, request):
-            return DummyResponse('anotherview')
+            return DummyResponse(b'anotherview')
         view.__call_permissive__ = anotherview
         self._registerView(request.registry, view, 'registered')
         iterable = self._callFUT(context, request, name='registered',
                                  secure=False)
-        self.assertEqual(iterable, ['anotherview'])
+        self.assertEqual(iterable, [b'anotherview'])
+
+    def test_verify_output_bytestring(self):
+        from pyramid.request import Request
+        from pyramid.config import Configurator
+        from pyramid.view import render_view
+        from webob.compat import text_type
+        config = Configurator(settings={})
+        def view(request):
+            request.response.text = text_type('<body></body>')
+            return request.response
+
+        config.add_view(name='test', view=view)
+        config.commit()
+
+        r = Request({})
+        r.registry = config.registry
+        self.assertEqual(render_view(object(), r, 'test'), b'<body></body>')
 
     def test_call_request_has_no_registry(self):
         request = self._makeRequest()
@@ -174,7 +278,7 @@ class RenderViewTests(BaseTest, unittest.TestCase):
         view = make_view(response)
         self._registerView(request.registry, view, 'registered')
         s = self._callFUT(context, request, name='registered', secure=True)
-        self.assertEqual(s, '')
+        self.assertEqual(s, b'')
 
     def test_call_view_registered_insecure_no_call_permissive(self):
         context = self._makeContext()
@@ -183,7 +287,7 @@ class RenderViewTests(BaseTest, unittest.TestCase):
         view = make_view(response)
         self._registerView(request.registry, view, 'registered')
         s = self._callFUT(context, request, name='registered', secure=False)
-        self.assertEqual(s, '')
+        self.assertEqual(s, b'')
 
     def test_call_view_registered_insecure_with_call_permissive(self):
         context = self._makeContext()
@@ -191,63 +295,18 @@ class RenderViewTests(BaseTest, unittest.TestCase):
         response = DummyResponse()
         view = make_view(response)
         def anotherview(context, request):
-            return DummyResponse('anotherview')
+            return DummyResponse(b'anotherview')
         view.__call_permissive__ = anotherview
         self._registerView(request.registry, view, 'registered')
         s = self._callFUT(context, request, name='registered', secure=False)
-        self.assertEqual(s, 'anotherview')
-
-class TestIsResponse(unittest.TestCase):
-    def setUp(self):
-        from zope.deprecation import __show__
-        __show__.off()
-
-    def tearDown(self):
-        from zope.deprecation import __show__
-        __show__.on()
-        
-    def _callFUT(self, *arg, **kw):
-        from pyramid.view import is_response
-        return is_response(*arg, **kw)
-
-    def test_is(self):
-        response = DummyResponse()
-        self.assertEqual(self._callFUT(response), True)
-
-    def test_isnt(self):
-        response = None
-        self.assertEqual(self._callFUT(response), False)
-
-    def test_isnt_no_headerlist(self):
-        class Response(object):
-            pass
-        resp = Response
-        resp.status = '200 OK'
-        resp.app_iter = []
-        self.assertEqual(self._callFUT(resp), False)
-
-    def test_isnt_no_status(self):
-        class Response(object):
-            pass
-        resp = Response
-        resp.app_iter = []
-        resp.headerlist = ()
-        self.assertEqual(self._callFUT(resp), False)
-
-    def test_isnt_no_app_iter(self):
-        class Response(object):
-            pass
-        resp = Response
-        resp.status = '200 OK'
-        resp.headerlist = ()
-        self.assertEqual(self._callFUT(resp), False)
+        self.assertEqual(s, b'anotherview')
 
 class TestViewConfigDecorator(unittest.TestCase):
     def setUp(self):
-        setUp()
+        testing.setUp()
 
     def tearDown(self):
-        tearDown()
+        testing.tearDown()
 
     def _getTargetClass(self):
         from pyramid.view import view_config
@@ -258,10 +317,7 @@ class TestViewConfigDecorator(unittest.TestCase):
 
     def test_create_defaults(self):
         decorator = self._makeOne()
-        self.assertEqual(decorator.name, '')
-        self.assertEqual(decorator.request_type, None)
-        self.assertEqual(decorator.context, None)
-        self.assertEqual(decorator.permission, None)
+        self.assertEqual(decorator.__dict__, {})
 
     def test_create_context_trumps_for(self):
         decorator = self._makeOne(context='123', for_='456')
@@ -272,9 +328,11 @@ class TestViewConfigDecorator(unittest.TestCase):
         self.assertEqual(decorator.context, '456')
         
     def test_create_nondefaults(self):
-        decorator = self._makeOne(name=None, request_type=None, for_=None,
-                                  permission='foo', mapper='mapper',
-                                  decorator='decorator', match_param='match_param')
+        decorator = self._makeOne(
+            name=None, request_type=None, for_=None,
+            permission='foo', mapper='mapper',
+            decorator='decorator', match_param='match_param'
+            )
         self.assertEqual(decorator.name, None)
         self.assertEqual(decorator.request_type, None)
         self.assertEqual(decorator.context, None)
@@ -282,6 +340,14 @@ class TestViewConfigDecorator(unittest.TestCase):
         self.assertEqual(decorator.mapper, 'mapper')
         self.assertEqual(decorator.decorator, 'decorator')
         self.assertEqual(decorator.match_param, 'match_param')
+
+    def test_create_with_other_predicates(self):
+        decorator = self._makeOne(foo=1)
+        self.assertEqual(decorator.foo, 1)
+
+    def test_create_decorator_tuple(self):
+        decorator = self._makeOne(decorator=('decorator1', 'decorator2'))
+        self.assertEqual(decorator.decorator, ('decorator1', 'decorator2'))
         
     def test_call_function(self):
         decorator = self._makeOne()
@@ -293,9 +359,11 @@ class TestViewConfigDecorator(unittest.TestCase):
         config = call_venusian(venusian)
         settings = config.settings
         self.assertEqual(len(settings), 1)
-        self.assertEqual(settings[0]['permission'], None)
-        self.assertEqual(settings[0]['context'], None)
-        self.assertEqual(settings[0]['request_type'], None)
+        self.assertEqual(len(settings), 1)
+        self.assertEqual(len(settings[0]), 3)
+        self.assertEqual(settings[0]['venusian'], venusian)
+        self.assertEqual(settings[0]['view'], None) # comes from call_venusian
+        self.assertEqual(settings[0]['_info'], 'codeinfo')
 
     def test_call_class(self):
         decorator = self._makeOne()
@@ -308,10 +376,11 @@ class TestViewConfigDecorator(unittest.TestCase):
         config = call_venusian(venusian)
         settings = config.settings
         self.assertEqual(len(settings), 1)
-        self.assertEqual(settings[0]['permission'], None)
-        self.assertEqual(settings[0]['context'], None)
-        self.assertEqual(settings[0]['request_type'], None)
+        self.assertEqual(len(settings[0]), 4)
+        self.assertEqual(settings[0]['venusian'], venusian)
+        self.assertEqual(settings[0]['view'], None) # comes from call_venusian
         self.assertEqual(settings[0]['attr'], 'foo')
+        self.assertEqual(settings[0]['_info'], 'codeinfo')
 
     def test_call_class_attr_already_set(self):
         decorator = self._makeOne(attr='abc')
@@ -324,10 +393,11 @@ class TestViewConfigDecorator(unittest.TestCase):
         config = call_venusian(venusian)
         settings = config.settings
         self.assertEqual(len(settings), 1)
-        self.assertEqual(settings[0]['permission'], None)
-        self.assertEqual(settings[0]['context'], None)
-        self.assertEqual(settings[0]['request_type'], None)
+        self.assertEqual(len(settings[0]), 4)
+        self.assertEqual(settings[0]['venusian'], venusian)
+        self.assertEqual(settings[0]['view'], None) # comes from call_venusian
         self.assertEqual(settings[0]['attr'], 'abc')
+        self.assertEqual(settings[0]['_info'], 'codeinfo')
 
     def test_stacking(self):
         decorator1 = self._makeOne(name='1')
@@ -407,8 +477,9 @@ class TestViewConfigDecorator(unittest.TestCase):
     def test_call_with_renderer_IRendererInfo(self):
         import pyramid.tests
         from pyramid.interfaces import IRendererInfo
+        @implementer(IRendererInfo)
         class DummyRendererHelper(object):
-            implements(IRendererInfo)
+            pass
         renderer_helper = DummyRendererHelper()
         decorator = self._makeOne(renderer=renderer_helper)
         venusian = DummyVenusian()
@@ -424,6 +495,14 @@ class TestViewConfigDecorator(unittest.TestCase):
         self.assertTrue(renderer is renderer_helper)
         self.assertEqual(config.pkg, pyramid.tests)
 
+    def test_call_withdepth(self):
+        decorator = self._makeOne(_depth=1)
+        venusian = DummyVenusian()
+        decorator.venusian = venusian
+        def foo(): pass
+        decorator(foo)
+        self.assertEqual(venusian.depth, 2)
+
 class Test_append_slash_notfound_view(BaseTest, unittest.TestCase):
     def _callFUT(self, context, request):
         from pyramid.view import append_slash_notfound_view
@@ -549,23 +628,38 @@ class Test_default_exceptionresponse_view(unittest.TestCase):
         result = self._callFUT(context, request)
         self.assertEqual(result, 'abc')
 
-class Test_static(unittest.TestCase):
-    def setUp(self):
-        from zope.deprecation import __show__
-        __show__.off()
-
-    def tearDown(self):
-        from zope.deprecation import __show__
-        __show__.on()
-
-    def _makeOne(self, path, package_name):
-        from pyramid.view import static
-        return static(path, package_name)
-        
+class Test_view_defaults(unittest.TestCase):
     def test_it(self):
-        path = 'fixtures'
-        view = self._makeOne(path, None)
-        self.assertEqual(view.docroot, 'fixtures')
+        from pyramid.view import view_defaults
+        @view_defaults(route_name='abc', renderer='def')
+        class Foo(object): pass
+        self.assertEqual(Foo.__view_defaults__['route_name'],'abc')
+        self.assertEqual(Foo.__view_defaults__['renderer'],'def')
+
+    def test_it_inheritance_not_overridden(self):
+        from pyramid.view import view_defaults
+        @view_defaults(route_name='abc', renderer='def')
+        class Foo(object): pass
+        class Bar(Foo): pass
+        self.assertEqual(Bar.__view_defaults__['route_name'],'abc')
+        self.assertEqual(Bar.__view_defaults__['renderer'],'def')
+
+    def test_it_inheritance_overriden(self):
+        from pyramid.view import view_defaults
+        @view_defaults(route_name='abc', renderer='def')
+        class Foo(object): pass
+        @view_defaults(route_name='ghi')
+        class Bar(Foo): pass
+        self.assertEqual(Bar.__view_defaults__['route_name'],'ghi')
+        self.assertFalse('renderer' in Bar.__view_defaults__)
+
+    def test_it_inheritance_overriden_empty(self):
+        from pyramid.view import view_defaults
+        @view_defaults(route_name='abc', renderer='def')
+        class Foo(object): pass
+        @view_defaults()
+        class Bar(Foo): pass
+        self.assertEqual(Bar.__view_defaults__, {})
 
 class ExceptionResponse(Exception):
     status = '404 Not Found'
@@ -589,10 +683,9 @@ class DummyRequest:
         self.environ = environ
         
 from pyramid.interfaces import IResponse
-from zope.interface import implements
 
+@implementer(IResponse)
 class DummyResponse(object):
-    implements(IResponse)
     headerlist = ()
     app_iter = ()
     status = '200 OK'
@@ -619,8 +712,9 @@ class DummyVenusian(object):
         self.info = info
         self.attachments = []
 
-    def attach(self, wrapped, callback, category=None):
+    def attach(self, wrapped, callback, category=None, depth=1):
         self.attachments.append((wrapped, callback, category))
+        self.depth = depth
         return self.info
 
 class DummyRegistry(object):
@@ -634,6 +728,8 @@ class DummyConfig(object):
     def add_view(self, **kw):
         self.settings.append(kw)
 
+    add_notfound_view = add_forbidden_view = add_view
+
     def with_package(self, pkg):
         self.pkg = pkg
         return self
